redhatopenshiftapi

package
v0.0.0-...-ba303d9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 10, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type OpenShiftClustersClientAPI

type OpenShiftClustersClientAPI interface {
	CreateOrUpdate(ctx context.Context, resourceGroupName string, resourceName string, parameters redhatopenshift.OpenShiftCluster) (result redhatopenshift.OpenShiftClustersCreateOrUpdateFuture, err error)
	Delete(ctx context.Context, resourceGroupName string, resourceName string) (result redhatopenshift.OpenShiftClustersDeleteFuture, err error)
	Get(ctx context.Context, resourceGroupName string, resourceName string) (result redhatopenshift.OpenShiftCluster, err error)
	List(ctx context.Context) (result redhatopenshift.OpenShiftClusterListPage, err error)
	ListComplete(ctx context.Context) (result redhatopenshift.OpenShiftClusterListIterator, err error)
	ListAdminCredentials(ctx context.Context, resourceGroupName string, resourceName string) (result redhatopenshift.OpenShiftClusterAdminKubeconfig, err error)
	ListByResourceGroup(ctx context.Context, resourceGroupName string) (result redhatopenshift.OpenShiftClusterListPage, err error)
	ListByResourceGroupComplete(ctx context.Context, resourceGroupName string) (result redhatopenshift.OpenShiftClusterListIterator, err error)
	ListCredentials(ctx context.Context, resourceGroupName string, resourceName string) (result redhatopenshift.OpenShiftClusterCredentials, err error)
	Update(ctx context.Context, resourceGroupName string, resourceName string, parameters redhatopenshift.OpenShiftClusterUpdate) (result redhatopenshift.OpenShiftClustersUpdateFuture, err error)
}

OpenShiftClustersClientAPI contains the set of methods on the OpenShiftClustersClient type.

type OpenShiftVersionsClientAPI

type OpenShiftVersionsClientAPI interface {
	Get(ctx context.Context, location string, openShiftVersion string) (result redhatopenshift.OpenShiftVersion, err error)
	List(ctx context.Context, location string) (result redhatopenshift.OpenShiftVersionListPage, err error)
	ListComplete(ctx context.Context, location string) (result redhatopenshift.OpenShiftVersionListIterator, err error)
}

OpenShiftVersionsClientAPI contains the set of methods on the OpenShiftVersionsClient type.

type OperationsClientAPI

type OperationsClientAPI interface {
	List(ctx context.Context) (result redhatopenshift.OperationListPage, err error)
	ListComplete(ctx context.Context) (result redhatopenshift.OperationListIterator, err error)
}

OperationsClientAPI contains the set of methods on the OperationsClient type.

type PlatformWorkloadIdentityRoleSetClientAPI

type PlatformWorkloadIdentityRoleSetClientAPI interface {
	Get(ctx context.Context, location string, openShiftMinorVersion string) (result redhatopenshift.PlatformWorkloadIdentityRoleSet, err error)
}

PlatformWorkloadIdentityRoleSetClientAPI contains the set of methods on the PlatformWorkloadIdentityRoleSetClient type.

type PlatformWorkloadIdentityRoleSetsClientAPI

type PlatformWorkloadIdentityRoleSetsClientAPI interface {
	List(ctx context.Context, location string) (result redhatopenshift.PlatformWorkloadIdentityRoleSetListPage, err error)
	ListComplete(ctx context.Context, location string) (result redhatopenshift.PlatformWorkloadIdentityRoleSetListIterator, err error)
}

PlatformWorkloadIdentityRoleSetsClientAPI contains the set of methods on the PlatformWorkloadIdentityRoleSetsClient type.

Jump to