Documentation
¶
Overview ¶
Package v1alpha1 is the v1alpha1 version of the API. +groupName=aro.openshift.io
Package v1alpha1 contains API Schema definitions for the aro v1alpha1 API group +kubebuilder:object:generate=true +groupName=aro.openshift.io
Index ¶
Constants ¶
const ( // not using iota to force a stable value mapping BannerDisabled BannerContent = "" BannerContactSupport BannerContent = "ContactSupport" SingletonClusterName = "cluster" InternetReachableFromMaster = "InternetReachableFromMaster" InternetReachableFromWorker = "InternetReachableFromWorker" MachineValid = "MachineValid" ServicePrincipalValid = "ServicePrincipalValid" ManagedUpgradeOperatorStatus = "ManagedUpgradeOperatorStatus" // advisor checks DefaultIngressCertificate = "DefaultIngressCertificate" DefaultClusterDNS = "DefaultClusterDNS" GuardRailsStatus = "GuardRailsStatus" )
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "aro.openshift.io", Version: "v1alpha1"} // SchemeGroupVersion manual hack SchemeGroupVersion = GroupVersion // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
func AllConditionTypes ¶
func AllConditionTypes() []string
AllConditionTypes is a operator conditions currently in use, any condition not in this list is not added to the operator.status.conditions list
func ClusterChecksTypes ¶
func ClusterChecksTypes() []string
ClusterChecksTypes represents checks performed on the cluster to verify basic functionality
Types ¶
type Banner ¶
type Banner struct {
Content BannerContent `json:"content,omitempty"`
}
Banner defines if a Banner should be shown to the customer
func (*Banner) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Banner.
func (*Banner) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type BannerContent ¶
type BannerContent string
type Cluster ¶
type Cluster struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ClusterSpec `json:"spec,omitempty"`
Status ClusterStatus `json:"status,omitempty"`
}
Cluster is the Schema for the clusters API +kubebuilder:object:root=true +genclient +genclient:nonNamespaced +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
func (*Cluster) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Cluster.
func (*Cluster) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Cluster) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ClusterList ¶
type ClusterList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Cluster `json:"items"`
}
ClusterList contains a list of Cluster +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
func (*ClusterList) DeepCopy ¶
func (in *ClusterList) DeepCopy() *ClusterList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterList.
func (*ClusterList) DeepCopyInto ¶
func (in *ClusterList) DeepCopyInto(out *ClusterList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ClusterList) DeepCopyObject ¶
func (in *ClusterList) DeepCopyObject() kruntime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ClusterSpec ¶
type ClusterSpec struct {
// ResourceID is the Azure resourceId of the cluster
ResourceID string `json:"resourceId,omitempty"`
ClusterResourceGroupID string `json:"clusterResourceGroupId,omitempty"`
Domain string `json:"domain,omitempty"`
ACRDomain string `json:"acrDomain,omitempty"`
AZEnvironment string `json:"azEnvironment,omitempty"`
Location string `json:"location,omitempty"`
InfraID string `json:"infraId,omitempty"`
StorageSuffix string `json:"storageSuffix,omitempty"`
ArchitectureVersion int `json:"architectureVersion,omitempty"`
GenevaLogging GenevaLoggingSpec `json:"genevaLogging,omitempty"`
InternetChecker InternetCheckerSpec `json:"internetChecker,omitempty"`
VnetID string `json:"vnetId,omitempty"`
APIIntIP string `json:"apiIntIP,omitempty"`
IngressIP string `json:"ingressIP,omitempty"`
GatewayDomains []string `json:"gatewayDomains,omitempty"`
GatewayPrivateEndpointIP string `json:"gatewayPrivateEndpointIP,omitempty"`
Banner Banner `json:"banner,omitempty"`
ServiceSubnets []string `json:"serviceSubnets,omitempty"`
// OperatorFlags defines feature gates for the ARO Operator
OperatorFlags OperatorFlags `json:"operatorflags,omitempty"`
}
ClusterSpec defines the desired state of Cluster
func (*ClusterSpec) DeepCopy ¶
func (in *ClusterSpec) DeepCopy() *ClusterSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterSpec.
func (*ClusterSpec) DeepCopyInto ¶
func (in *ClusterSpec) DeepCopyInto(out *ClusterSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ClusterStatus ¶
type ClusterStatus struct {
OperatorVersion string `json:"operatorVersion,omitempty"`
Conditions []operatorv1.OperatorCondition `json:"conditions,omitempty"`
RedHatKeysPresent []string `json:"redHatKeysPresent,omitempty"`
}
ClusterStatus defines the observed state of Cluster
func (*ClusterStatus) DeepCopy ¶
func (in *ClusterStatus) DeepCopy() *ClusterStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterStatus.
func (*ClusterStatus) DeepCopyInto ¶
func (in *ClusterStatus) DeepCopyInto(out *ClusterStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GenevaLoggingSpec ¶
type GenevaLoggingSpec struct {
// +kubebuilder:validation:Pattern:=`[0-9]+.[0-9]+`
ConfigVersion string `json:"configVersion,omitempty"`
// +kubebuilder:validation:Enum=AROClusterLogsINT;AROClusterLogsPROD;AROClusterLogs
MonitoringGCSAccount string `json:"monitoringGCSAccount,omitempty"`
// +kubebuilder:validation:Enum=DiagnosticsProd;Test;CaFairfax
MonitoringGCSEnvironment string `json:"monitoringGCSEnvironment,omitempty"`
// +kubebuilder:validation:Enum=AROClusterLogsINT;AROClusterLogsPROD;AROClusterLogs
MonitoringGCSNamespace string `json:"monitoringGCSNamespace,omitempty"`
}
func (*GenevaLoggingSpec) DeepCopy ¶
func (in *GenevaLoggingSpec) DeepCopy() *GenevaLoggingSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GenevaLoggingSpec.
func (*GenevaLoggingSpec) DeepCopyInto ¶
func (in *GenevaLoggingSpec) DeepCopyInto(out *GenevaLoggingSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type InternetCheckerSpec ¶
type InternetCheckerSpec struct {
URLs []string `json:"urls,omitempty"`
}
func (*InternetCheckerSpec) DeepCopy ¶
func (in *InternetCheckerSpec) DeepCopy() *InternetCheckerSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new InternetCheckerSpec.
func (*InternetCheckerSpec) DeepCopyInto ¶
func (in *InternetCheckerSpec) DeepCopyInto(out *InternetCheckerSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type OperatorFlags ¶
func (OperatorFlags) DeepCopy ¶
func (in OperatorFlags) DeepCopy() OperatorFlags
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new OperatorFlags.
func (OperatorFlags) DeepCopyInto ¶
func (in OperatorFlags) DeepCopyInto(out *OperatorFlags)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (OperatorFlags) GetSimpleBoolean ¶
func (f OperatorFlags) GetSimpleBoolean(key string) bool
func (OperatorFlags) GetWithDefault ¶
func (f OperatorFlags) GetWithDefault(key string, sentinel string) string