Documentation
¶
Overview ¶
Package v1alpha1 is the v1alpha1 version of the API. +groupName=preview.aro.openshift.io
Package v1alpha1 contains API Schema definitions for the aro v1alpha1 API group +kubebuilder:object:generate=true +groupName=preview.aro.openshift.io
Index ¶
Constants ¶
const (
SingletonPreviewFeatureName = "cluster"
)
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "preview.aro.openshift.io", Version: "v1alpha1"} // SchemeGroupVersion manual hack SchemeGroupVersion = GroupVersion // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type NSGFlowLogs ¶
type NSGFlowLogs struct {
// Enabled defines the behaviour of the reconciler:
// when true the controller will try to reach the desired configuration,
// when false it will try to disable the flow logs.
Enabled bool `json:"enabled"`
// Version defines version of NSG flow log.
// +kubebuilder:default:=2
// +kubebuilder:validation:Enum=1;2
Version int `json:"version,omitempty"`
// NetworkWatcherID specifies the ID of the network watcher.
NetworkWatcherID string `json:"networkWatcherID,omitempty"`
// StorageAccountResourceID of the storage account used for collecting the flow logs.
// Must be in the same region of flow log.
StorageAccountResourceID string `json:"storageAccountResourceId,omitempty"`
// RetentionDays specifies how many days the flowlogs should be retained.
// +kubebuilder:default:=90
RetentionDays int32 `json:"retentionDays,omitempty"`
// Required for TrafficAnalytics.
// Must be in the same region of flow log.
TrafficAnalyticsLogAnalyticsWorkspaceID string `json:"trafficAnalyticsLogAnalyticsWorkspaceId,omitempty"`
// Interval at which to conduct flow analytics. Values: 60m, 10m. Default: 60m.
// +kubebuilder:default:="60m"
// +kubebuilder:validation:Enum="60m";"10m"
TrafficAnalyticsInterval metav1.Duration `json:"trafficAnalyticsInterval,omitempty"`
}
NSGFlowLogs defines NSG flow logs configuration
func (*NSGFlowLogs) DeepCopy ¶
func (in *NSGFlowLogs) DeepCopy() *NSGFlowLogs
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NSGFlowLogs.
func (*NSGFlowLogs) DeepCopyInto ¶
func (in *NSGFlowLogs) DeepCopyInto(out *NSGFlowLogs)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PreviewFeature ¶
type PreviewFeature struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec PreviewFeatureSpec `json:"spec,omitempty"`
Status PreviewFeatureStatus `json:"status,omitempty"`
}
PreviewFeature is the Schema for the preview feature API +kubebuilder:object:root=true +genclient +genclient:nonNamespaced +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
func (*PreviewFeature) DeepCopy ¶
func (in *PreviewFeature) DeepCopy() *PreviewFeature
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PreviewFeature.
func (*PreviewFeature) DeepCopyInto ¶
func (in *PreviewFeature) DeepCopyInto(out *PreviewFeature)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PreviewFeature) DeepCopyObject ¶
func (in *PreviewFeature) DeepCopyObject() kruntime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type PreviewFeatureList ¶
type PreviewFeatureList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []PreviewFeature `json:"items"`
}
PreviewFeatureList contains a list of PreviewFeatures +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
func (*PreviewFeatureList) DeepCopy ¶
func (in *PreviewFeatureList) DeepCopy() *PreviewFeatureList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PreviewFeatureList.
func (*PreviewFeatureList) DeepCopyInto ¶
func (in *PreviewFeatureList) DeepCopyInto(out *PreviewFeatureList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PreviewFeatureList) DeepCopyObject ¶
func (in *PreviewFeatureList) DeepCopyObject() kruntime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type PreviewFeatureSpec ¶
type PreviewFeatureSpec struct {
// NSGFlowLogs contains configuration for NSG flow logs.
// Omit the configuration if you don't want the controller
// to reconcile NSG flow logs.
NSGFlowLogs *NSGFlowLogs `json:"nsgFlowLogs,omitempty"`
}
PreviewFeatureSpec defines the preview feature for ARO
func (*PreviewFeatureSpec) DeepCopy ¶
func (in *PreviewFeatureSpec) DeepCopy() *PreviewFeatureSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PreviewFeatureSpec.
func (*PreviewFeatureSpec) DeepCopyInto ¶
func (in *PreviewFeatureSpec) DeepCopyInto(out *PreviewFeatureSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PreviewFeatureStatus ¶
type PreviewFeatureStatus struct {
OperatorVersion string `json:"operatorVersion,omitempty"`
Conditions []operatorv1.OperatorCondition `json:"conditions,omitempty"`
}
PreviewFeatureStatus defines the observed state of PreviewFeature
func (*PreviewFeatureStatus) DeepCopy ¶
func (in *PreviewFeatureStatus) DeepCopy() *PreviewFeatureStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PreviewFeatureStatus.
func (*PreviewFeatureStatus) DeepCopyInto ¶
func (in *PreviewFeatureStatus) DeepCopyInto(out *PreviewFeatureStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.