Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Kubeconfig ¶
type Kubeconfig struct {
Log *logrus.Entry
BaseAccessLog *logrus.Entry
AuditLog *logrus.Entry
OtelAuditClient audit.Client
DbPortal database.Portal
Env env.Core
ReverseProxy *httputil.ReverseProxy
// contains filtered or unexported fields
}
func (*Kubeconfig) New ¶
func (k *Kubeconfig) New(w http.ResponseWriter, r *http.Request)
New creates a New PortalDocument allowing kubeconfig access to a cluster for 6 hours and returns a kubeconfig with the temporary credentials
Click to show internal directories.
Click to hide internal directories.