graphsdk

package
v0.0.0-...-96f79f1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 13, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type GraphBaseServiceClient

GraphBaseServiceClient the main entry point of the SDK, exposes the configuration and the fluent API.

func NewGraphBaseServiceClient

NewGraphBaseServiceClient instantiates a new GraphBaseServiceClient and sets the default values.

func (*GraphBaseServiceClient) Applications

Applications provides operations to manage the collection of application entities. returns a *ApplicationsRequestBuilder when successful

func (*GraphBaseServiceClient) ServicePrincipals

ServicePrincipals provides operations to manage the collection of servicePrincipal entities. returns a *ServicePrincipalsRequestBuilder when successful

Directories

Path Synopsis

Jump to