serviceprincipals

package
v0.0.0-...-1a55767 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 11, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ParseGetExpandQueryParameterType

func ParseGetExpandQueryParameterType(v string) (any, error)

func ParseGetOrderbyQueryParameterType

func ParseGetOrderbyQueryParameterType(v string) (any, error)

func ParseGetSelectQueryParameterType

func ParseGetSelectQueryParameterType(v string) (any, error)

func SerializeGetExpandQueryParameterType

func SerializeGetExpandQueryParameterType(values []GetExpandQueryParameterType) []string

func SerializeGetOrderbyQueryParameterType

func SerializeGetOrderbyQueryParameterType(values []GetOrderbyQueryParameterType) []string

func SerializeGetSelectQueryParameterType

func SerializeGetSelectQueryParameterType(values []GetSelectQueryParameterType) []string

Types

type GetExpandQueryParameterType

type GetExpandQueryParameterType int

Provides operations to manage the collection of servicePrincipal entities.

const (
	ASTERISK_GETEXPANDQUERYPARAMETERTYPE GetExpandQueryParameterType = iota
	APPMANAGEMENTPOLICIES_GETEXPANDQUERYPARAMETERTYPE
	APPROLEASSIGNEDTO_GETEXPANDQUERYPARAMETERTYPE
	APPROLEASSIGNMENTS_GETEXPANDQUERYPARAMETERTYPE
	CLAIMSMAPPINGPOLICIES_GETEXPANDQUERYPARAMETERTYPE
	CREATEDOBJECTS_GETEXPANDQUERYPARAMETERTYPE
	DELEGATEDPERMISSIONCLASSIFICATIONS_GETEXPANDQUERYPARAMETERTYPE
	ENDPOINTS_GETEXPANDQUERYPARAMETERTYPE
	FEDERATEDIDENTITYCREDENTIALS_GETEXPANDQUERYPARAMETERTYPE
	HOMEREALMDISCOVERYPOLICIES_GETEXPANDQUERYPARAMETERTYPE
	MEMBEROF_GETEXPANDQUERYPARAMETERTYPE
	OAUTH2PERMISSIONGRANTS_GETEXPANDQUERYPARAMETERTYPE
	OWNEDOBJECTS_GETEXPANDQUERYPARAMETERTYPE
	OWNERS_GETEXPANDQUERYPARAMETERTYPE
	TOKENISSUANCEPOLICIES_GETEXPANDQUERYPARAMETERTYPE
	TOKENLIFETIMEPOLICIES_GETEXPANDQUERYPARAMETERTYPE
	TRANSITIVEMEMBEROF_GETEXPANDQUERYPARAMETERTYPE
	SYNCHRONIZATION_GETEXPANDQUERYPARAMETERTYPE
)

func (GetExpandQueryParameterType) String

type GetOrderbyQueryParameterType

type GetOrderbyQueryParameterType int

Provides operations to manage the collection of servicePrincipal entities.

const (
	ID_GETORDERBYQUERYPARAMETERTYPE GetOrderbyQueryParameterType = iota
	IDDESC_GETORDERBYQUERYPARAMETERTYPE
	DELETEDDATETIME_GETORDERBYQUERYPARAMETERTYPE
	DELETEDDATETIMEDESC_GETORDERBYQUERYPARAMETERTYPE
	ACCOUNTENABLED_GETORDERBYQUERYPARAMETERTYPE
	ACCOUNTENABLEDDESC_GETORDERBYQUERYPARAMETERTYPE
	ADDINS_GETORDERBYQUERYPARAMETERTYPE
	ADDINSDESC_GETORDERBYQUERYPARAMETERTYPE
	ALTERNATIVENAMES_GETORDERBYQUERYPARAMETERTYPE
	ALTERNATIVENAMESDESC_GETORDERBYQUERYPARAMETERTYPE
	APPDESCRIPTION_GETORDERBYQUERYPARAMETERTYPE
	APPDESCRIPTIONDESC_GETORDERBYQUERYPARAMETERTYPE
	APPDISPLAYNAME_GETORDERBYQUERYPARAMETERTYPE
	APPDISPLAYNAMEDESC_GETORDERBYQUERYPARAMETERTYPE
	APPID_GETORDERBYQUERYPARAMETERTYPE
	APPIDDESC_GETORDERBYQUERYPARAMETERTYPE
	APPLICATIONTEMPLATEID_GETORDERBYQUERYPARAMETERTYPE
	APPLICATIONTEMPLATEIDDESC_GETORDERBYQUERYPARAMETERTYPE
	APPOWNERORGANIZATIONID_GETORDERBYQUERYPARAMETERTYPE
	APPOWNERORGANIZATIONIDDESC_GETORDERBYQUERYPARAMETERTYPE
	APPROLEASSIGNMENTREQUIRED_GETORDERBYQUERYPARAMETERTYPE
	APPROLEASSIGNMENTREQUIREDDESC_GETORDERBYQUERYPARAMETERTYPE
	APPROLES_GETORDERBYQUERYPARAMETERTYPE
	APPROLESDESC_GETORDERBYQUERYPARAMETERTYPE
	CUSTOMSECURITYATTRIBUTES_GETORDERBYQUERYPARAMETERTYPE
	CUSTOMSECURITYATTRIBUTESDESC_GETORDERBYQUERYPARAMETERTYPE
	DESCRIPTION_GETORDERBYQUERYPARAMETERTYPE
	DESCRIPTIONDESC_GETORDERBYQUERYPARAMETERTYPE
	DISABLEDBYMICROSOFTSTATUS_GETORDERBYQUERYPARAMETERTYPE
	DISABLEDBYMICROSOFTSTATUSDESC_GETORDERBYQUERYPARAMETERTYPE
	DISPLAYNAME_GETORDERBYQUERYPARAMETERTYPE
	DISPLAYNAMEDESC_GETORDERBYQUERYPARAMETERTYPE
	HOMEPAGE_GETORDERBYQUERYPARAMETERTYPE
	HOMEPAGEDESC_GETORDERBYQUERYPARAMETERTYPE
	INFO_GETORDERBYQUERYPARAMETERTYPE
	INFODESC_GETORDERBYQUERYPARAMETERTYPE
	KEYCREDENTIALS_GETORDERBYQUERYPARAMETERTYPE
	KEYCREDENTIALSDESC_GETORDERBYQUERYPARAMETERTYPE
	LOGINURL_GETORDERBYQUERYPARAMETERTYPE
	LOGINURLDESC_GETORDERBYQUERYPARAMETERTYPE
	LOGOUTURL_GETORDERBYQUERYPARAMETERTYPE
	LOGOUTURLDESC_GETORDERBYQUERYPARAMETERTYPE
	NOTES_GETORDERBYQUERYPARAMETERTYPE
	NOTESDESC_GETORDERBYQUERYPARAMETERTYPE
	NOTIFICATIONEMAILADDRESSES_GETORDERBYQUERYPARAMETERTYPE
	NOTIFICATIONEMAILADDRESSESDESC_GETORDERBYQUERYPARAMETERTYPE
	OAUTH2PERMISSIONSCOPES_GETORDERBYQUERYPARAMETERTYPE
	OAUTH2PERMISSIONSCOPESDESC_GETORDERBYQUERYPARAMETERTYPE
	PASSWORDCREDENTIALS_GETORDERBYQUERYPARAMETERTYPE
	PASSWORDCREDENTIALSDESC_GETORDERBYQUERYPARAMETERTYPE
	PREFERREDSINGLESIGNONMODE_GETORDERBYQUERYPARAMETERTYPE
	PREFERREDSINGLESIGNONMODEDESC_GETORDERBYQUERYPARAMETERTYPE
	PREFERREDTOKENSIGNINGKEYTHUMBPRINT_GETORDERBYQUERYPARAMETERTYPE
	PREFERREDTOKENSIGNINGKEYTHUMBPRINTDESC_GETORDERBYQUERYPARAMETERTYPE
	REPLYURLS_GETORDERBYQUERYPARAMETERTYPE
	REPLYURLSDESC_GETORDERBYQUERYPARAMETERTYPE
	RESOURCESPECIFICAPPLICATIONPERMISSIONS_GETORDERBYQUERYPARAMETERTYPE
	RESOURCESPECIFICAPPLICATIONPERMISSIONSDESC_GETORDERBYQUERYPARAMETERTYPE
	SAMLSINGLESIGNONSETTINGS_GETORDERBYQUERYPARAMETERTYPE
	SAMLSINGLESIGNONSETTINGSDESC_GETORDERBYQUERYPARAMETERTYPE
	SERVICEPRINCIPALNAMES_GETORDERBYQUERYPARAMETERTYPE
	SERVICEPRINCIPALNAMESDESC_GETORDERBYQUERYPARAMETERTYPE
	SERVICEPRINCIPALTYPE_GETORDERBYQUERYPARAMETERTYPE
	SERVICEPRINCIPALTYPEDESC_GETORDERBYQUERYPARAMETERTYPE
	SIGNINAUDIENCE_GETORDERBYQUERYPARAMETERTYPE
	SIGNINAUDIENCEDESC_GETORDERBYQUERYPARAMETERTYPE
	TAGS_GETORDERBYQUERYPARAMETERTYPE
	TAGSDESC_GETORDERBYQUERYPARAMETERTYPE
	TOKENENCRYPTIONKEYID_GETORDERBYQUERYPARAMETERTYPE
	TOKENENCRYPTIONKEYIDDESC_GETORDERBYQUERYPARAMETERTYPE
	VERIFIEDPUBLISHER_GETORDERBYQUERYPARAMETERTYPE
	VERIFIEDPUBLISHERDESC_GETORDERBYQUERYPARAMETERTYPE
)

func (GetOrderbyQueryParameterType) String

type GetSelectQueryParameterType

type GetSelectQueryParameterType int

Provides operations to manage the collection of servicePrincipal entities.

const (
	ID_GETSELECTQUERYPARAMETERTYPE GetSelectQueryParameterType = iota
	DELETEDDATETIME_GETSELECTQUERYPARAMETERTYPE
	ACCOUNTENABLED_GETSELECTQUERYPARAMETERTYPE
	ADDINS_GETSELECTQUERYPARAMETERTYPE
	ALTERNATIVENAMES_GETSELECTQUERYPARAMETERTYPE
	APPDESCRIPTION_GETSELECTQUERYPARAMETERTYPE
	APPDISPLAYNAME_GETSELECTQUERYPARAMETERTYPE
	APPID_GETSELECTQUERYPARAMETERTYPE
	APPLICATIONTEMPLATEID_GETSELECTQUERYPARAMETERTYPE
	APPOWNERORGANIZATIONID_GETSELECTQUERYPARAMETERTYPE
	APPROLEASSIGNMENTREQUIRED_GETSELECTQUERYPARAMETERTYPE
	APPROLES_GETSELECTQUERYPARAMETERTYPE
	CUSTOMSECURITYATTRIBUTES_GETSELECTQUERYPARAMETERTYPE
	DESCRIPTION_GETSELECTQUERYPARAMETERTYPE
	DISABLEDBYMICROSOFTSTATUS_GETSELECTQUERYPARAMETERTYPE
	DISPLAYNAME_GETSELECTQUERYPARAMETERTYPE
	HOMEPAGE_GETSELECTQUERYPARAMETERTYPE
	INFO_GETSELECTQUERYPARAMETERTYPE
	KEYCREDENTIALS_GETSELECTQUERYPARAMETERTYPE
	LOGINURL_GETSELECTQUERYPARAMETERTYPE
	LOGOUTURL_GETSELECTQUERYPARAMETERTYPE
	NOTES_GETSELECTQUERYPARAMETERTYPE
	NOTIFICATIONEMAILADDRESSES_GETSELECTQUERYPARAMETERTYPE
	OAUTH2PERMISSIONSCOPES_GETSELECTQUERYPARAMETERTYPE
	PASSWORDCREDENTIALS_GETSELECTQUERYPARAMETERTYPE
	PREFERREDSINGLESIGNONMODE_GETSELECTQUERYPARAMETERTYPE
	PREFERREDTOKENSIGNINGKEYTHUMBPRINT_GETSELECTQUERYPARAMETERTYPE
	REPLYURLS_GETSELECTQUERYPARAMETERTYPE
	RESOURCESPECIFICAPPLICATIONPERMISSIONS_GETSELECTQUERYPARAMETERTYPE
	SAMLSINGLESIGNONSETTINGS_GETSELECTQUERYPARAMETERTYPE
	SERVICEPRINCIPALNAMES_GETSELECTQUERYPARAMETERTYPE
	SERVICEPRINCIPALTYPE_GETSELECTQUERYPARAMETERTYPE
	SIGNINAUDIENCE_GETSELECTQUERYPARAMETERTYPE
	TAGS_GETSELECTQUERYPARAMETERTYPE
	TOKENENCRYPTIONKEYID_GETSELECTQUERYPARAMETERTYPE
	VERIFIEDPUBLISHER_GETSELECTQUERYPARAMETERTYPE
	APPMANAGEMENTPOLICIES_GETSELECTQUERYPARAMETERTYPE
	APPROLEASSIGNEDTO_GETSELECTQUERYPARAMETERTYPE
	APPROLEASSIGNMENTS_GETSELECTQUERYPARAMETERTYPE
	CLAIMSMAPPINGPOLICIES_GETSELECTQUERYPARAMETERTYPE
	CREATEDOBJECTS_GETSELECTQUERYPARAMETERTYPE
	DELEGATEDPERMISSIONCLASSIFICATIONS_GETSELECTQUERYPARAMETERTYPE
	ENDPOINTS_GETSELECTQUERYPARAMETERTYPE
	FEDERATEDIDENTITYCREDENTIALS_GETSELECTQUERYPARAMETERTYPE
	HOMEREALMDISCOVERYPOLICIES_GETSELECTQUERYPARAMETERTYPE
	MEMBEROF_GETSELECTQUERYPARAMETERTYPE
	OAUTH2PERMISSIONGRANTS_GETSELECTQUERYPARAMETERTYPE
	OWNEDOBJECTS_GETSELECTQUERYPARAMETERTYPE
	OWNERS_GETSELECTQUERYPARAMETERTYPE
	TOKENISSUANCEPOLICIES_GETSELECTQUERYPARAMETERTYPE
	TOKENLIFETIMEPOLICIES_GETSELECTQUERYPARAMETERTYPE
	TRANSITIVEMEMBEROF_GETSELECTQUERYPARAMETERTYPE
	SYNCHRONIZATION_GETSELECTQUERYPARAMETERTYPE
)

func (GetSelectQueryParameterType) String

type ServicePrincipalItemRequestBuilder

ServicePrincipalItemRequestBuilder provides operations to manage the collection of servicePrincipal entities.

func NewServicePrincipalItemRequestBuilder

NewServicePrincipalItemRequestBuilder instantiates a new ServicePrincipalItemRequestBuilder and sets the default values.

func NewServicePrincipalItemRequestBuilderInternal

func NewServicePrincipalItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ServicePrincipalItemRequestBuilder

NewServicePrincipalItemRequestBuilderInternal instantiates a new ServicePrincipalItemRequestBuilder and sets the default values.

func (*ServicePrincipalItemRequestBuilder) Delete

Delete delete a servicePrincipal object. returns a ODataError error when the service returns a 4XX or 5XX status code Find more info here

func (*ServicePrincipalItemRequestBuilder) Get

Get retrieve the properties and relationships of a servicePrincipal object. returns a ServicePrincipalable when successful returns a ODataError error when the service returns a 4XX or 5XX status code Find more info here

func (*ServicePrincipalItemRequestBuilder) Patch

Patch update entity in servicePrincipals returns a ServicePrincipalable when successful returns a ODataError error when the service returns a 4XX or 5XX status code

func (*ServicePrincipalItemRequestBuilder) ToDeleteRequestInformation

ToDeleteRequestInformation delete a servicePrincipal object. returns a *RequestInformation when successful

func (*ServicePrincipalItemRequestBuilder) ToGetRequestInformation

ToGetRequestInformation retrieve the properties and relationships of a servicePrincipal object. returns a *RequestInformation when successful

func (*ServicePrincipalItemRequestBuilder) ToPatchRequestInformation

ToPatchRequestInformation update entity in servicePrincipals returns a *RequestInformation when successful

func (*ServicePrincipalItemRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ServicePrincipalItemRequestBuilder when successful

type ServicePrincipalItemRequestBuilderDeleteRequestConfiguration

type ServicePrincipalItemRequestBuilderDeleteRequestConfiguration struct {
	// Request headers
	Headers *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestHeaders
	// Request options
	Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}

ServicePrincipalItemRequestBuilderDeleteRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.

type ServicePrincipalItemRequestBuilderGetQueryParameters

type ServicePrincipalItemRequestBuilderGetQueryParameters struct {
	// Expand related entities
	// Deprecated: This property is deprecated, use ExpandAsGetExpandQueryParameterType instead
	Expand []string `uriparametername:"%24expand"`
	// Expand related entities
	ExpandAsGetExpandQueryParameterType []i2fc5abaf8a8003b4658a18005838ee0206e1d85a5b2097a9506dd0ceb90ac20d.GetExpandQueryParameterType `uriparametername:"%24expand"`
	// Select properties to be returned
	// Deprecated: This property is deprecated, use SelectAsGetSelectQueryParameterType instead
	Select []string `uriparametername:"%24select"`
	// Select properties to be returned
	SelectAsGetSelectQueryParameterType []i2fc5abaf8a8003b4658a18005838ee0206e1d85a5b2097a9506dd0ceb90ac20d.GetSelectQueryParameterType `uriparametername:"%24select"`
}

ServicePrincipalItemRequestBuilderGetQueryParameters retrieve the properties and relationships of a servicePrincipal object.

type ServicePrincipalItemRequestBuilderGetRequestConfiguration

type ServicePrincipalItemRequestBuilderGetRequestConfiguration struct {
	// Request headers
	Headers *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestHeaders
	// Request options
	Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
	// Request query parameters
	QueryParameters *ServicePrincipalItemRequestBuilderGetQueryParameters
}

ServicePrincipalItemRequestBuilderGetRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.

type ServicePrincipalItemRequestBuilderPatchRequestConfiguration

type ServicePrincipalItemRequestBuilderPatchRequestConfiguration struct {
	// Request headers
	Headers *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestHeaders
	// Request options
	Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}

ServicePrincipalItemRequestBuilderPatchRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.

type ServicePrincipalsRequestBuilder

ServicePrincipalsRequestBuilder provides operations to manage the collection of servicePrincipal entities.

func NewServicePrincipalsRequestBuilder

NewServicePrincipalsRequestBuilder instantiates a new ServicePrincipalsRequestBuilder and sets the default values.

func NewServicePrincipalsRequestBuilderInternal

func NewServicePrincipalsRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ServicePrincipalsRequestBuilder

NewServicePrincipalsRequestBuilderInternal instantiates a new ServicePrincipalsRequestBuilder and sets the default values.

func (*ServicePrincipalsRequestBuilder) ByServicePrincipalId

func (m *ServicePrincipalsRequestBuilder) ByServicePrincipalId(servicePrincipalId string) *ServicePrincipalItemRequestBuilder

ByServicePrincipalId provides operations to manage the collection of servicePrincipal entities. returns a *ServicePrincipalItemRequestBuilder when successful

func (*ServicePrincipalsRequestBuilder) Get

Get retrieve a list of servicePrincipal objects. returns a ServicePrincipalCollectionResponseable when successful returns a ODataError error when the service returns a 4XX or 5XX status code Find more info here

func (*ServicePrincipalsRequestBuilder) Post

Post create a new servicePrincipal object. returns a ServicePrincipalable when successful returns a ODataError error when the service returns a 4XX or 5XX status code Find more info here

func (*ServicePrincipalsRequestBuilder) ToGetRequestInformation

ToGetRequestInformation retrieve a list of servicePrincipal objects. returns a *RequestInformation when successful

func (*ServicePrincipalsRequestBuilder) ToPostRequestInformation

ToPostRequestInformation create a new servicePrincipal object. returns a *RequestInformation when successful

func (*ServicePrincipalsRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ServicePrincipalsRequestBuilder when successful

type ServicePrincipalsRequestBuilderGetQueryParameters

type ServicePrincipalsRequestBuilderGetQueryParameters struct {
	// Include count of items
	Count *bool `uriparametername:"%24count"`
	// Expand related entities
	// Deprecated: This property is deprecated, use ExpandAsGetExpandQueryParameterType instead
	Expand []string `uriparametername:"%24expand"`
	// Expand related entities
	ExpandAsGetExpandQueryParameterType []GetExpandQueryParameterType `uriparametername:"%24expand"`
	// Filter items by property values
	Filter *string `uriparametername:"%24filter"`
	// Order items by property values
	// Deprecated: This property is deprecated, use OrderbyAsGetOrderbyQueryParameterType instead
	Orderby []string `uriparametername:"%24orderby"`
	// Order items by property values
	OrderbyAsGetOrderbyQueryParameterType []GetOrderbyQueryParameterType `uriparametername:"%24orderby"`
	// Search items by search phrases
	Search *string `uriparametername:"%24search"`
	// Select properties to be returned
	// Deprecated: This property is deprecated, use SelectAsGetSelectQueryParameterType instead
	Select []string `uriparametername:"%24select"`
	// Select properties to be returned
	SelectAsGetSelectQueryParameterType []GetSelectQueryParameterType `uriparametername:"%24select"`
	// Skip the first n items
	Skip *int32 `uriparametername:"%24skip"`
	// Show only the first n items
	Top *int32 `uriparametername:"%24top"`
}

ServicePrincipalsRequestBuilderGetQueryParameters retrieve a list of servicePrincipal objects.

type ServicePrincipalsRequestBuilderGetRequestConfiguration

type ServicePrincipalsRequestBuilderGetRequestConfiguration struct {
	// Request headers
	Headers *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestHeaders
	// Request options
	Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
	// Request query parameters
	QueryParameters *ServicePrincipalsRequestBuilderGetQueryParameters
}

ServicePrincipalsRequestBuilderGetRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.

type ServicePrincipalsRequestBuilderPostRequestConfiguration

type ServicePrincipalsRequestBuilderPostRequestConfiguration struct {
	// Request headers
	Headers *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestHeaders
	// Request options
	Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}

ServicePrincipalsRequestBuilderPostRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.

Directories

Path Synopsis

Jump to