Documentation
¶
Overview ¶
Package mock_armnetwork is a generated GoMock package.
Index ¶
- type MockFlowLogsClientInterface
- func (m *MockFlowLogsClientInterface) CreateOrUpdateAndWait(ctx context.Context, resourceGroupName, networkWatcherName, flowLogName string, ...) error
- func (m *MockFlowLogsClientInterface) DeleteAndWait(ctx context.Context, resourceGroupName, networkWatcherName, flowLogName string, ...) error
- func (m *MockFlowLogsClientInterface) EXPECT() *MockFlowLogsClientInterfaceMockRecorder
- func (m *MockFlowLogsClientInterface) Get(ctx context.Context, resourceGroupName, networkWatcherName, flowLogName string, ...) (armnetwork.FlowLogsClientGetResponse, error)
- type MockFlowLogsClientInterfaceMockRecorder
- func (mr *MockFlowLogsClientInterfaceMockRecorder) CreateOrUpdateAndWait(...) *gomock.Call
- func (mr *MockFlowLogsClientInterfaceMockRecorder) DeleteAndWait(ctx, resourceGroupName, networkWatcherName, flowLogName, options any) *gomock.Call
- func (mr *MockFlowLogsClientInterfaceMockRecorder) Get(ctx, resourceGroupName, networkWatcherName, flowLogName, options any) *gomock.Call
- type MockInterfacesClient
- func (m *MockInterfacesClient) CreateOrUpdateAndWait(ctx context.Context, resourceGroupName, networkInterfaceName string, ...) error
- func (m *MockInterfacesClient) DeleteAndWait(ctx context.Context, resourceGroupName, networkInterfaceName string, ...) error
- func (m *MockInterfacesClient) EXPECT() *MockInterfacesClientMockRecorder
- func (m *MockInterfacesClient) Get(ctx context.Context, resourceGroupName, networkInterfaceName string, ...) (armnetwork.InterfacesClientGetResponse, error)
- func (m *MockInterfacesClient) GetEffectiveRouteTableAndWait(ctx context.Context, resourceGroupName, networkInterfaceName string, ...) (*armnetwork.EffectiveRouteListResult, error)
- func (m *MockInterfacesClient) List(ctx context.Context, resourceGroupName string, ...) ([]*armnetwork.Interface, error)
- type MockInterfacesClientMockRecorder
- func (mr *MockInterfacesClientMockRecorder) CreateOrUpdateAndWait(ctx, resourceGroupName, networkInterfaceName, parameters, options any) *gomock.Call
- func (mr *MockInterfacesClientMockRecorder) DeleteAndWait(ctx, resourceGroupName, networkInterfaceName, options any) *gomock.Call
- func (mr *MockInterfacesClientMockRecorder) Get(ctx, resourceGroupName, networkInterfaceName, options any) *gomock.Call
- func (mr *MockInterfacesClientMockRecorder) GetEffectiveRouteTableAndWait(ctx, resourceGroupName, networkInterfaceName, options any) *gomock.Call
- func (mr *MockInterfacesClientMockRecorder) List(ctx, resourceGroupName, options any) *gomock.Call
- type MockLoadBalancerBackendAddressPoolsClient
- type MockLoadBalancerBackendAddressPoolsClientMockRecorder
- type MockLoadBalancersClient
- func (m *MockLoadBalancersClient) CreateOrUpdateAndWait(ctx context.Context, resourceGroupName, loadBalancerName string, ...) error
- func (m *MockLoadBalancersClient) EXPECT() *MockLoadBalancersClientMockRecorder
- func (m *MockLoadBalancersClient) Get(ctx context.Context, resourceGroupName, loadBalancerName string, ...) (armnetwork.LoadBalancersClientGetResponse, error)
- type MockLoadBalancersClientMockRecorder
- type MockPrivateEndpointsClient
- func (m *MockPrivateEndpointsClient) CreateOrUpdateAndWait(ctx context.Context, resourceGroupName, privateEndpointName string, ...) error
- func (m *MockPrivateEndpointsClient) DeleteAndWait(ctx context.Context, resourceGroupName, publicIPAddressName string, ...) error
- func (m *MockPrivateEndpointsClient) EXPECT() *MockPrivateEndpointsClientMockRecorder
- func (m *MockPrivateEndpointsClient) Get(ctx context.Context, resourceGroupName, privateEndpointName string, ...) (armnetwork.PrivateEndpointsClientGetResponse, error)
- type MockPrivateEndpointsClientMockRecorder
- func (mr *MockPrivateEndpointsClientMockRecorder) CreateOrUpdateAndWait(ctx, resourceGroupName, privateEndpointName, parameters, options any) *gomock.Call
- func (mr *MockPrivateEndpointsClientMockRecorder) DeleteAndWait(ctx, resourceGroupName, publicIPAddressName, options any) *gomock.Call
- func (mr *MockPrivateEndpointsClientMockRecorder) Get(ctx, resourceGroupName, privateEndpointName, options any) *gomock.Call
- type MockPrivateLinkServicesClient
- func (m *MockPrivateLinkServicesClient) CreateOrUpdateAndWait(ctx context.Context, resourceGroupName, serviceName string, ...) error
- func (m *MockPrivateLinkServicesClient) DeletePrivateEndpointConnectionAndWait(ctx context.Context, resourceGroupName, serviceName, peConnectionName string, ...) error
- func (m *MockPrivateLinkServicesClient) EXPECT() *MockPrivateLinkServicesClientMockRecorder
- func (m *MockPrivateLinkServicesClient) Get(ctx context.Context, resourceGroupName, serviceName string, ...) (armnetwork.PrivateLinkServicesClientGetResponse, error)
- func (m *MockPrivateLinkServicesClient) List(ctx context.Context, resourceGroupName string, ...) ([]*armnetwork.PrivateLinkService, error)
- func (m *MockPrivateLinkServicesClient) UpdatePrivateEndpointConnection(ctx context.Context, resourceGroupName, serviceName, peConnectionName string, ...) (armnetwork.PrivateLinkServicesClientUpdatePrivateEndpointConnectionResponse, ...)
- type MockPrivateLinkServicesClientMockRecorder
- func (mr *MockPrivateLinkServicesClientMockRecorder) CreateOrUpdateAndWait(ctx, resourceGroupName, serviceName, parameters, options any) *gomock.Call
- func (mr *MockPrivateLinkServicesClientMockRecorder) DeletePrivateEndpointConnectionAndWait(ctx, resourceGroupName, serviceName, peConnectionName, options any) *gomock.Call
- func (mr *MockPrivateLinkServicesClientMockRecorder) Get(ctx, resourceGroupName, serviceName, options any) *gomock.Call
- func (mr *MockPrivateLinkServicesClientMockRecorder) List(ctx, resourceGroupName, options any) *gomock.Call
- func (mr *MockPrivateLinkServicesClientMockRecorder) UpdatePrivateEndpointConnection(ctx, resourceGroupName, serviceName, peConnectionName, parameters, options any) *gomock.Call
- type MockPublicIPAddressesClient
- func (m *MockPublicIPAddressesClient) CreateOrUpdateAndWait(ctx context.Context, resourceGroupName, publicIPAddressName string, ...) error
- func (m *MockPublicIPAddressesClient) DeleteAndWait(ctx context.Context, resourceGroupName, publicIPAddressName string, ...) error
- func (m *MockPublicIPAddressesClient) EXPECT() *MockPublicIPAddressesClientMockRecorder
- func (m *MockPublicIPAddressesClient) Get(ctx context.Context, resourceGroupName, publicIPAddressName string, ...) (armnetwork.PublicIPAddressesClientGetResponse, error)
- func (m *MockPublicIPAddressesClient) List(ctx context.Context, resourceGroupName string, ...) ([]*armnetwork.PublicIPAddress, error)
- type MockPublicIPAddressesClientMockRecorder
- func (mr *MockPublicIPAddressesClientMockRecorder) CreateOrUpdateAndWait(ctx, resourceGroupName, publicIPAddressName, parameters, options any) *gomock.Call
- func (mr *MockPublicIPAddressesClientMockRecorder) DeleteAndWait(ctx, resourceGroupName, publicIPAddressName, options any) *gomock.Call
- func (mr *MockPublicIPAddressesClientMockRecorder) Get(ctx, resourceGroupName, publicIPAddressName, options any) *gomock.Call
- func (mr *MockPublicIPAddressesClientMockRecorder) List(ctx, resourceGroupName, options any) *gomock.Call
- type MockRouteTablesClient
- func (m *MockRouteTablesClient) DeleteAndWait(ctx context.Context, resourceGroupName, routeTableName string, ...) error
- func (m *MockRouteTablesClient) EXPECT() *MockRouteTablesClientMockRecorder
- func (m *MockRouteTablesClient) Get(ctx context.Context, resourceGroupName, routeTableName string, ...) (armnetwork.RouteTablesClientGetResponse, error)
- type MockRouteTablesClientMockRecorder
- type MockSecurityGroupsClient
- func (m *MockSecurityGroupsClient) CreateOrUpdateAndWait(ctx context.Context, resourceGroupName, networkSecurityGroupName string, ...) error
- func (m *MockSecurityGroupsClient) DeleteAndWait(ctx context.Context, resourceGroupName, networkSecurityGroupName string, ...) error
- func (m *MockSecurityGroupsClient) EXPECT() *MockSecurityGroupsClientMockRecorder
- func (m *MockSecurityGroupsClient) Get(ctx context.Context, resourceGroupName, networkSecurityGroupName string, ...) (armnetwork.SecurityGroupsClientGetResponse, error)
- func (m *MockSecurityGroupsClient) List(ctx context.Context, resourceGroupName string, ...) ([]*armnetwork.SecurityGroup, error)
- type MockSecurityGroupsClientMockRecorder
- func (mr *MockSecurityGroupsClientMockRecorder) CreateOrUpdateAndWait(ctx, resourceGroupName, networkSecurityGroupName, parameters, options any) *gomock.Call
- func (mr *MockSecurityGroupsClientMockRecorder) DeleteAndWait(ctx, resourceGroupName, networkSecurityGroupName, options any) *gomock.Call
- func (mr *MockSecurityGroupsClientMockRecorder) Get(ctx, resourceGroupName, networkSecurityGroupName, options any) *gomock.Call
- func (mr *MockSecurityGroupsClientMockRecorder) List(ctx, resourceGroupName, options any) *gomock.Call
- type MockSubnetsClient
- func (m *MockSubnetsClient) CreateOrUpdateAndWait(ctx context.Context, resourceGroupName, virtualNetworkName, subnetName string, ...) error
- func (m *MockSubnetsClient) DeleteAndWait(ctx context.Context, resourceGroupName, virtualNetworkName, subnetName string, ...) error
- func (m *MockSubnetsClient) EXPECT() *MockSubnetsClientMockRecorder
- func (m *MockSubnetsClient) Get(ctx context.Context, resourceGroupName, virtualNetworkName, subnetName string, ...) (armnetwork.SubnetsClientGetResponse, error)
- func (m *MockSubnetsClient) List(ctx context.Context, resourceGroupName, virtualNetworkName string, ...) ([]*armnetwork.Subnet, error)
- type MockSubnetsClientMockRecorder
- func (mr *MockSubnetsClientMockRecorder) CreateOrUpdateAndWait(...) *gomock.Call
- func (mr *MockSubnetsClientMockRecorder) DeleteAndWait(ctx, resourceGroupName, virtualNetworkName, subnetName, options any) *gomock.Call
- func (mr *MockSubnetsClientMockRecorder) Get(ctx, resourceGroupName, virtualNetworkName, subnetName, options any) *gomock.Call
- func (mr *MockSubnetsClientMockRecorder) List(ctx, resourceGroupName, virtualNetworkName, options any) *gomock.Call
- type MockUsagesClient
- type MockUsagesClientMockRecorder
- type MockVirtualNetworksClient
- type MockVirtualNetworksClientMockRecorder
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockFlowLogsClientInterface ¶
type MockFlowLogsClientInterface struct {
// contains filtered or unexported fields
}
MockFlowLogsClientInterface is a mock of FlowLogsClientInterface interface.
func NewMockFlowLogsClientInterface ¶
func NewMockFlowLogsClientInterface(ctrl *gomock.Controller) *MockFlowLogsClientInterface
NewMockFlowLogsClientInterface creates a new mock instance.
func (*MockFlowLogsClientInterface) CreateOrUpdateAndWait ¶
func (m *MockFlowLogsClientInterface) CreateOrUpdateAndWait(ctx context.Context, resourceGroupName, networkWatcherName, flowLogName string, parameters armnetwork.FlowLog, options *armnetwork.FlowLogsClientBeginCreateOrUpdateOptions) error
CreateOrUpdateAndWait mocks base method.
func (*MockFlowLogsClientInterface) DeleteAndWait ¶
func (m *MockFlowLogsClientInterface) DeleteAndWait(ctx context.Context, resourceGroupName, networkWatcherName, flowLogName string, options *armnetwork.FlowLogsClientBeginDeleteOptions) error
DeleteAndWait mocks base method.
func (*MockFlowLogsClientInterface) EXPECT ¶
func (m *MockFlowLogsClientInterface) EXPECT() *MockFlowLogsClientInterfaceMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockFlowLogsClientInterface) Get ¶
func (m *MockFlowLogsClientInterface) Get(ctx context.Context, resourceGroupName, networkWatcherName, flowLogName string, options *armnetwork.FlowLogsClientGetOptions) (armnetwork.FlowLogsClientGetResponse, error)
Get mocks base method.
type MockFlowLogsClientInterfaceMockRecorder ¶
type MockFlowLogsClientInterfaceMockRecorder struct {
// contains filtered or unexported fields
}
MockFlowLogsClientInterfaceMockRecorder is the mock recorder for MockFlowLogsClientInterface.
func (*MockFlowLogsClientInterfaceMockRecorder) CreateOrUpdateAndWait ¶
func (mr *MockFlowLogsClientInterfaceMockRecorder) CreateOrUpdateAndWait(ctx, resourceGroupName, networkWatcherName, flowLogName, parameters, options any) *gomock.Call
CreateOrUpdateAndWait indicates an expected call of CreateOrUpdateAndWait.
func (*MockFlowLogsClientInterfaceMockRecorder) DeleteAndWait ¶
func (mr *MockFlowLogsClientInterfaceMockRecorder) DeleteAndWait(ctx, resourceGroupName, networkWatcherName, flowLogName, options any) *gomock.Call
DeleteAndWait indicates an expected call of DeleteAndWait.
type MockInterfacesClient ¶
type MockInterfacesClient struct {
// contains filtered or unexported fields
}
MockInterfacesClient is a mock of InterfacesClient interface.
func NewMockInterfacesClient ¶
func NewMockInterfacesClient(ctrl *gomock.Controller) *MockInterfacesClient
NewMockInterfacesClient creates a new mock instance.
func (*MockInterfacesClient) CreateOrUpdateAndWait ¶
func (m *MockInterfacesClient) CreateOrUpdateAndWait(ctx context.Context, resourceGroupName, networkInterfaceName string, parameters armnetwork.Interface, options *armnetwork.InterfacesClientBeginCreateOrUpdateOptions) error
CreateOrUpdateAndWait mocks base method.
func (*MockInterfacesClient) DeleteAndWait ¶
func (m *MockInterfacesClient) DeleteAndWait(ctx context.Context, resourceGroupName, networkInterfaceName string, options *armnetwork.InterfacesClientBeginDeleteOptions) error
DeleteAndWait mocks base method.
func (*MockInterfacesClient) EXPECT ¶
func (m *MockInterfacesClient) EXPECT() *MockInterfacesClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockInterfacesClient) Get ¶
func (m *MockInterfacesClient) Get(ctx context.Context, resourceGroupName, networkInterfaceName string, options *armnetwork.InterfacesClientGetOptions) (armnetwork.InterfacesClientGetResponse, error)
Get mocks base method.
func (*MockInterfacesClient) GetEffectiveRouteTableAndWait ¶
func (m *MockInterfacesClient) GetEffectiveRouteTableAndWait(ctx context.Context, resourceGroupName, networkInterfaceName string, options *armnetwork.InterfacesClientBeginGetEffectiveRouteTableOptions) (*armnetwork.EffectiveRouteListResult, error)
GetEffectiveRouteTableAndWait mocks base method.
func (*MockInterfacesClient) List ¶
func (m *MockInterfacesClient) List(ctx context.Context, resourceGroupName string, options *armnetwork.InterfacesClientListOptions) ([]*armnetwork.Interface, error)
List mocks base method.
type MockInterfacesClientMockRecorder ¶
type MockInterfacesClientMockRecorder struct {
// contains filtered or unexported fields
}
MockInterfacesClientMockRecorder is the mock recorder for MockInterfacesClient.
func (*MockInterfacesClientMockRecorder) CreateOrUpdateAndWait ¶
func (mr *MockInterfacesClientMockRecorder) CreateOrUpdateAndWait(ctx, resourceGroupName, networkInterfaceName, parameters, options any) *gomock.Call
CreateOrUpdateAndWait indicates an expected call of CreateOrUpdateAndWait.
func (*MockInterfacesClientMockRecorder) DeleteAndWait ¶
func (mr *MockInterfacesClientMockRecorder) DeleteAndWait(ctx, resourceGroupName, networkInterfaceName, options any) *gomock.Call
DeleteAndWait indicates an expected call of DeleteAndWait.
func (*MockInterfacesClientMockRecorder) Get ¶
func (mr *MockInterfacesClientMockRecorder) Get(ctx, resourceGroupName, networkInterfaceName, options any) *gomock.Call
Get indicates an expected call of Get.
func (*MockInterfacesClientMockRecorder) GetEffectiveRouteTableAndWait ¶
func (mr *MockInterfacesClientMockRecorder) GetEffectiveRouteTableAndWait(ctx, resourceGroupName, networkInterfaceName, options any) *gomock.Call
GetEffectiveRouteTableAndWait indicates an expected call of GetEffectiveRouteTableAndWait.
type MockLoadBalancerBackendAddressPoolsClient ¶
type MockLoadBalancerBackendAddressPoolsClient struct {
// contains filtered or unexported fields
}
MockLoadBalancerBackendAddressPoolsClient is a mock of LoadBalancerBackendAddressPoolsClient interface.
func NewMockLoadBalancerBackendAddressPoolsClient ¶
func NewMockLoadBalancerBackendAddressPoolsClient(ctrl *gomock.Controller) *MockLoadBalancerBackendAddressPoolsClient
NewMockLoadBalancerBackendAddressPoolsClient creates a new mock instance.
func (*MockLoadBalancerBackendAddressPoolsClient) EXPECT ¶
func (m *MockLoadBalancerBackendAddressPoolsClient) EXPECT() *MockLoadBalancerBackendAddressPoolsClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockLoadBalancerBackendAddressPoolsClient) Get ¶
func (m *MockLoadBalancerBackendAddressPoolsClient) Get(ctx context.Context, resourceGroupName, loadBalancerName, backendAddressPoolName string, options *armnetwork.LoadBalancerBackendAddressPoolsClientGetOptions) (armnetwork.LoadBalancerBackendAddressPoolsClientGetResponse, error)
Get mocks base method.
type MockLoadBalancerBackendAddressPoolsClientMockRecorder ¶
type MockLoadBalancerBackendAddressPoolsClientMockRecorder struct {
// contains filtered or unexported fields
}
MockLoadBalancerBackendAddressPoolsClientMockRecorder is the mock recorder for MockLoadBalancerBackendAddressPoolsClient.
type MockLoadBalancersClient ¶
type MockLoadBalancersClient struct {
// contains filtered or unexported fields
}
MockLoadBalancersClient is a mock of LoadBalancersClient interface.
func NewMockLoadBalancersClient ¶
func NewMockLoadBalancersClient(ctrl *gomock.Controller) *MockLoadBalancersClient
NewMockLoadBalancersClient creates a new mock instance.
func (*MockLoadBalancersClient) CreateOrUpdateAndWait ¶
func (m *MockLoadBalancersClient) CreateOrUpdateAndWait(ctx context.Context, resourceGroupName, loadBalancerName string, parameters armnetwork.LoadBalancer, options *armnetwork.LoadBalancersClientBeginCreateOrUpdateOptions) error
CreateOrUpdateAndWait mocks base method.
func (*MockLoadBalancersClient) EXPECT ¶
func (m *MockLoadBalancersClient) EXPECT() *MockLoadBalancersClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockLoadBalancersClient) Get ¶
func (m *MockLoadBalancersClient) Get(ctx context.Context, resourceGroupName, loadBalancerName string, options *armnetwork.LoadBalancersClientGetOptions) (armnetwork.LoadBalancersClientGetResponse, error)
Get mocks base method.
type MockLoadBalancersClientMockRecorder ¶
type MockLoadBalancersClientMockRecorder struct {
// contains filtered or unexported fields
}
MockLoadBalancersClientMockRecorder is the mock recorder for MockLoadBalancersClient.
func (*MockLoadBalancersClientMockRecorder) CreateOrUpdateAndWait ¶
func (mr *MockLoadBalancersClientMockRecorder) CreateOrUpdateAndWait(ctx, resourceGroupName, loadBalancerName, parameters, options any) *gomock.Call
CreateOrUpdateAndWait indicates an expected call of CreateOrUpdateAndWait.
type MockPrivateEndpointsClient ¶
type MockPrivateEndpointsClient struct {
// contains filtered or unexported fields
}
MockPrivateEndpointsClient is a mock of PrivateEndpointsClient interface.
func NewMockPrivateEndpointsClient ¶
func NewMockPrivateEndpointsClient(ctrl *gomock.Controller) *MockPrivateEndpointsClient
NewMockPrivateEndpointsClient creates a new mock instance.
func (*MockPrivateEndpointsClient) CreateOrUpdateAndWait ¶
func (m *MockPrivateEndpointsClient) CreateOrUpdateAndWait(ctx context.Context, resourceGroupName, privateEndpointName string, parameters armnetwork.PrivateEndpoint, options *armnetwork.PrivateEndpointsClientBeginCreateOrUpdateOptions) error
CreateOrUpdateAndWait mocks base method.
func (*MockPrivateEndpointsClient) DeleteAndWait ¶
func (m *MockPrivateEndpointsClient) DeleteAndWait(ctx context.Context, resourceGroupName, publicIPAddressName string, options *armnetwork.PrivateEndpointsClientBeginDeleteOptions) error
DeleteAndWait mocks base method.
func (*MockPrivateEndpointsClient) EXPECT ¶
func (m *MockPrivateEndpointsClient) EXPECT() *MockPrivateEndpointsClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockPrivateEndpointsClient) Get ¶
func (m *MockPrivateEndpointsClient) Get(ctx context.Context, resourceGroupName, privateEndpointName string, options *armnetwork.PrivateEndpointsClientGetOptions) (armnetwork.PrivateEndpointsClientGetResponse, error)
Get mocks base method.
type MockPrivateEndpointsClientMockRecorder ¶
type MockPrivateEndpointsClientMockRecorder struct {
// contains filtered or unexported fields
}
MockPrivateEndpointsClientMockRecorder is the mock recorder for MockPrivateEndpointsClient.
func (*MockPrivateEndpointsClientMockRecorder) CreateOrUpdateAndWait ¶
func (mr *MockPrivateEndpointsClientMockRecorder) CreateOrUpdateAndWait(ctx, resourceGroupName, privateEndpointName, parameters, options any) *gomock.Call
CreateOrUpdateAndWait indicates an expected call of CreateOrUpdateAndWait.
func (*MockPrivateEndpointsClientMockRecorder) DeleteAndWait ¶
func (mr *MockPrivateEndpointsClientMockRecorder) DeleteAndWait(ctx, resourceGroupName, publicIPAddressName, options any) *gomock.Call
DeleteAndWait indicates an expected call of DeleteAndWait.
type MockPrivateLinkServicesClient ¶
type MockPrivateLinkServicesClient struct {
// contains filtered or unexported fields
}
MockPrivateLinkServicesClient is a mock of PrivateLinkServicesClient interface.
func NewMockPrivateLinkServicesClient ¶
func NewMockPrivateLinkServicesClient(ctrl *gomock.Controller) *MockPrivateLinkServicesClient
NewMockPrivateLinkServicesClient creates a new mock instance.
func (*MockPrivateLinkServicesClient) CreateOrUpdateAndWait ¶
func (m *MockPrivateLinkServicesClient) CreateOrUpdateAndWait(ctx context.Context, resourceGroupName, serviceName string, parameters armnetwork.PrivateLinkService, options *armnetwork.PrivateLinkServicesClientBeginCreateOrUpdateOptions) error
CreateOrUpdateAndWait mocks base method.
func (*MockPrivateLinkServicesClient) DeletePrivateEndpointConnectionAndWait ¶
func (m *MockPrivateLinkServicesClient) DeletePrivateEndpointConnectionAndWait(ctx context.Context, resourceGroupName, serviceName, peConnectionName string, options *armnetwork.PrivateLinkServicesClientBeginDeletePrivateEndpointConnectionOptions) error
DeletePrivateEndpointConnectionAndWait mocks base method.
func (*MockPrivateLinkServicesClient) EXPECT ¶
func (m *MockPrivateLinkServicesClient) EXPECT() *MockPrivateLinkServicesClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockPrivateLinkServicesClient) Get ¶
func (m *MockPrivateLinkServicesClient) Get(ctx context.Context, resourceGroupName, serviceName string, options *armnetwork.PrivateLinkServicesClientGetOptions) (armnetwork.PrivateLinkServicesClientGetResponse, error)
Get mocks base method.
func (*MockPrivateLinkServicesClient) List ¶
func (m *MockPrivateLinkServicesClient) List(ctx context.Context, resourceGroupName string, options *armnetwork.PrivateLinkServicesClientListOptions) ([]*armnetwork.PrivateLinkService, error)
List mocks base method.
func (*MockPrivateLinkServicesClient) UpdatePrivateEndpointConnection ¶
func (m *MockPrivateLinkServicesClient) UpdatePrivateEndpointConnection(ctx context.Context, resourceGroupName, serviceName, peConnectionName string, parameters armnetwork.PrivateEndpointConnection, options *armnetwork.PrivateLinkServicesClientUpdatePrivateEndpointConnectionOptions) (armnetwork.PrivateLinkServicesClientUpdatePrivateEndpointConnectionResponse, error)
UpdatePrivateEndpointConnection mocks base method.
type MockPrivateLinkServicesClientMockRecorder ¶
type MockPrivateLinkServicesClientMockRecorder struct {
// contains filtered or unexported fields
}
MockPrivateLinkServicesClientMockRecorder is the mock recorder for MockPrivateLinkServicesClient.
func (*MockPrivateLinkServicesClientMockRecorder) CreateOrUpdateAndWait ¶
func (mr *MockPrivateLinkServicesClientMockRecorder) CreateOrUpdateAndWait(ctx, resourceGroupName, serviceName, parameters, options any) *gomock.Call
CreateOrUpdateAndWait indicates an expected call of CreateOrUpdateAndWait.
func (*MockPrivateLinkServicesClientMockRecorder) DeletePrivateEndpointConnectionAndWait ¶
func (mr *MockPrivateLinkServicesClientMockRecorder) DeletePrivateEndpointConnectionAndWait(ctx, resourceGroupName, serviceName, peConnectionName, options any) *gomock.Call
DeletePrivateEndpointConnectionAndWait indicates an expected call of DeletePrivateEndpointConnectionAndWait.
func (*MockPrivateLinkServicesClientMockRecorder) Get ¶
func (mr *MockPrivateLinkServicesClientMockRecorder) Get(ctx, resourceGroupName, serviceName, options any) *gomock.Call
Get indicates an expected call of Get.
func (*MockPrivateLinkServicesClientMockRecorder) List ¶
func (mr *MockPrivateLinkServicesClientMockRecorder) List(ctx, resourceGroupName, options any) *gomock.Call
List indicates an expected call of List.
func (*MockPrivateLinkServicesClientMockRecorder) UpdatePrivateEndpointConnection ¶
func (mr *MockPrivateLinkServicesClientMockRecorder) UpdatePrivateEndpointConnection(ctx, resourceGroupName, serviceName, peConnectionName, parameters, options any) *gomock.Call
UpdatePrivateEndpointConnection indicates an expected call of UpdatePrivateEndpointConnection.
type MockPublicIPAddressesClient ¶
type MockPublicIPAddressesClient struct {
// contains filtered or unexported fields
}
MockPublicIPAddressesClient is a mock of PublicIPAddressesClient interface.
func NewMockPublicIPAddressesClient ¶
func NewMockPublicIPAddressesClient(ctrl *gomock.Controller) *MockPublicIPAddressesClient
NewMockPublicIPAddressesClient creates a new mock instance.
func (*MockPublicIPAddressesClient) CreateOrUpdateAndWait ¶
func (m *MockPublicIPAddressesClient) CreateOrUpdateAndWait(ctx context.Context, resourceGroupName, publicIPAddressName string, parameters armnetwork.PublicIPAddress, options *armnetwork.PublicIPAddressesClientBeginCreateOrUpdateOptions) error
CreateOrUpdateAndWait mocks base method.
func (*MockPublicIPAddressesClient) DeleteAndWait ¶
func (m *MockPublicIPAddressesClient) DeleteAndWait(ctx context.Context, resourceGroupName, publicIPAddressName string, options *armnetwork.PublicIPAddressesClientBeginDeleteOptions) error
DeleteAndWait mocks base method.
func (*MockPublicIPAddressesClient) EXPECT ¶
func (m *MockPublicIPAddressesClient) EXPECT() *MockPublicIPAddressesClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockPublicIPAddressesClient) Get ¶
func (m *MockPublicIPAddressesClient) Get(ctx context.Context, resourceGroupName, publicIPAddressName string, options *armnetwork.PublicIPAddressesClientGetOptions) (armnetwork.PublicIPAddressesClientGetResponse, error)
Get mocks base method.
func (*MockPublicIPAddressesClient) List ¶
func (m *MockPublicIPAddressesClient) List(ctx context.Context, resourceGroupName string, options *armnetwork.PublicIPAddressesClientListOptions) ([]*armnetwork.PublicIPAddress, error)
List mocks base method.
type MockPublicIPAddressesClientMockRecorder ¶
type MockPublicIPAddressesClientMockRecorder struct {
// contains filtered or unexported fields
}
MockPublicIPAddressesClientMockRecorder is the mock recorder for MockPublicIPAddressesClient.
func (*MockPublicIPAddressesClientMockRecorder) CreateOrUpdateAndWait ¶
func (mr *MockPublicIPAddressesClientMockRecorder) CreateOrUpdateAndWait(ctx, resourceGroupName, publicIPAddressName, parameters, options any) *gomock.Call
CreateOrUpdateAndWait indicates an expected call of CreateOrUpdateAndWait.
func (*MockPublicIPAddressesClientMockRecorder) DeleteAndWait ¶
func (mr *MockPublicIPAddressesClientMockRecorder) DeleteAndWait(ctx, resourceGroupName, publicIPAddressName, options any) *gomock.Call
DeleteAndWait indicates an expected call of DeleteAndWait.
type MockRouteTablesClient ¶
type MockRouteTablesClient struct {
// contains filtered or unexported fields
}
MockRouteTablesClient is a mock of RouteTablesClient interface.
func NewMockRouteTablesClient ¶
func NewMockRouteTablesClient(ctrl *gomock.Controller) *MockRouteTablesClient
NewMockRouteTablesClient creates a new mock instance.
func (*MockRouteTablesClient) DeleteAndWait ¶
func (m *MockRouteTablesClient) DeleteAndWait(ctx context.Context, resourceGroupName, routeTableName string, options *armnetwork.RouteTablesClientBeginDeleteOptions) error
DeleteAndWait mocks base method.
func (*MockRouteTablesClient) EXPECT ¶
func (m *MockRouteTablesClient) EXPECT() *MockRouteTablesClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockRouteTablesClient) Get ¶
func (m *MockRouteTablesClient) Get(ctx context.Context, resourceGroupName, routeTableName string, options *armnetwork.RouteTablesClientGetOptions) (armnetwork.RouteTablesClientGetResponse, error)
Get mocks base method.
type MockRouteTablesClientMockRecorder ¶
type MockRouteTablesClientMockRecorder struct {
// contains filtered or unexported fields
}
MockRouteTablesClientMockRecorder is the mock recorder for MockRouteTablesClient.
func (*MockRouteTablesClientMockRecorder) DeleteAndWait ¶
func (mr *MockRouteTablesClientMockRecorder) DeleteAndWait(ctx, resourceGroupName, routeTableName, options any) *gomock.Call
DeleteAndWait indicates an expected call of DeleteAndWait.
type MockSecurityGroupsClient ¶
type MockSecurityGroupsClient struct {
// contains filtered or unexported fields
}
MockSecurityGroupsClient is a mock of SecurityGroupsClient interface.
func NewMockSecurityGroupsClient ¶
func NewMockSecurityGroupsClient(ctrl *gomock.Controller) *MockSecurityGroupsClient
NewMockSecurityGroupsClient creates a new mock instance.
func (*MockSecurityGroupsClient) CreateOrUpdateAndWait ¶
func (m *MockSecurityGroupsClient) CreateOrUpdateAndWait(ctx context.Context, resourceGroupName, networkSecurityGroupName string, parameters armnetwork.SecurityGroup, options *armnetwork.SecurityGroupsClientBeginCreateOrUpdateOptions) error
CreateOrUpdateAndWait mocks base method.
func (*MockSecurityGroupsClient) DeleteAndWait ¶
func (m *MockSecurityGroupsClient) DeleteAndWait(ctx context.Context, resourceGroupName, networkSecurityGroupName string, options *armnetwork.SecurityGroupsClientBeginDeleteOptions) error
DeleteAndWait mocks base method.
func (*MockSecurityGroupsClient) EXPECT ¶
func (m *MockSecurityGroupsClient) EXPECT() *MockSecurityGroupsClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockSecurityGroupsClient) Get ¶
func (m *MockSecurityGroupsClient) Get(ctx context.Context, resourceGroupName, networkSecurityGroupName string, options *armnetwork.SecurityGroupsClientGetOptions) (armnetwork.SecurityGroupsClientGetResponse, error)
Get mocks base method.
func (*MockSecurityGroupsClient) List ¶
func (m *MockSecurityGroupsClient) List(ctx context.Context, resourceGroupName string, options *armnetwork.SecurityGroupsClientListOptions) ([]*armnetwork.SecurityGroup, error)
List mocks base method.
type MockSecurityGroupsClientMockRecorder ¶
type MockSecurityGroupsClientMockRecorder struct {
// contains filtered or unexported fields
}
MockSecurityGroupsClientMockRecorder is the mock recorder for MockSecurityGroupsClient.
func (*MockSecurityGroupsClientMockRecorder) CreateOrUpdateAndWait ¶
func (mr *MockSecurityGroupsClientMockRecorder) CreateOrUpdateAndWait(ctx, resourceGroupName, networkSecurityGroupName, parameters, options any) *gomock.Call
CreateOrUpdateAndWait indicates an expected call of CreateOrUpdateAndWait.
func (*MockSecurityGroupsClientMockRecorder) DeleteAndWait ¶
func (mr *MockSecurityGroupsClientMockRecorder) DeleteAndWait(ctx, resourceGroupName, networkSecurityGroupName, options any) *gomock.Call
DeleteAndWait indicates an expected call of DeleteAndWait.
type MockSubnetsClient ¶
type MockSubnetsClient struct {
// contains filtered or unexported fields
}
MockSubnetsClient is a mock of SubnetsClient interface.
func NewMockSubnetsClient ¶
func NewMockSubnetsClient(ctrl *gomock.Controller) *MockSubnetsClient
NewMockSubnetsClient creates a new mock instance.
func (*MockSubnetsClient) CreateOrUpdateAndWait ¶
func (m *MockSubnetsClient) CreateOrUpdateAndWait(ctx context.Context, resourceGroupName, virtualNetworkName, subnetName string, subnetParameters armnetwork.Subnet, options *armnetwork.SubnetsClientBeginCreateOrUpdateOptions) error
CreateOrUpdateAndWait mocks base method.
func (*MockSubnetsClient) DeleteAndWait ¶
func (m *MockSubnetsClient) DeleteAndWait(ctx context.Context, resourceGroupName, virtualNetworkName, subnetName string, options *armnetwork.SubnetsClientBeginDeleteOptions) error
DeleteAndWait mocks base method.
func (*MockSubnetsClient) EXPECT ¶
func (m *MockSubnetsClient) EXPECT() *MockSubnetsClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockSubnetsClient) Get ¶
func (m *MockSubnetsClient) Get(ctx context.Context, resourceGroupName, virtualNetworkName, subnetName string, options *armnetwork.SubnetsClientGetOptions) (armnetwork.SubnetsClientGetResponse, error)
Get mocks base method.
func (*MockSubnetsClient) List ¶
func (m *MockSubnetsClient) List(ctx context.Context, resourceGroupName, virtualNetworkName string, options *armnetwork.SubnetsClientListOptions) ([]*armnetwork.Subnet, error)
List mocks base method.
type MockSubnetsClientMockRecorder ¶
type MockSubnetsClientMockRecorder struct {
// contains filtered or unexported fields
}
MockSubnetsClientMockRecorder is the mock recorder for MockSubnetsClient.
func (*MockSubnetsClientMockRecorder) CreateOrUpdateAndWait ¶
func (mr *MockSubnetsClientMockRecorder) CreateOrUpdateAndWait(ctx, resourceGroupName, virtualNetworkName, subnetName, subnetParameters, options any) *gomock.Call
CreateOrUpdateAndWait indicates an expected call of CreateOrUpdateAndWait.
func (*MockSubnetsClientMockRecorder) DeleteAndWait ¶
func (mr *MockSubnetsClientMockRecorder) DeleteAndWait(ctx, resourceGroupName, virtualNetworkName, subnetName, options any) *gomock.Call
DeleteAndWait indicates an expected call of DeleteAndWait.
type MockUsagesClient ¶
type MockUsagesClient struct {
// contains filtered or unexported fields
}
MockUsagesClient is a mock of UsagesClient interface.
func NewMockUsagesClient ¶
func NewMockUsagesClient(ctrl *gomock.Controller) *MockUsagesClient
NewMockUsagesClient creates a new mock instance.
func (*MockUsagesClient) EXPECT ¶
func (m *MockUsagesClient) EXPECT() *MockUsagesClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockUsagesClient) List ¶
func (m *MockUsagesClient) List(ctx context.Context, location string, options *armnetwork.UsagesClientListOptions) ([]*armnetwork.Usage, error)
List mocks base method.
type MockUsagesClientMockRecorder ¶
type MockUsagesClientMockRecorder struct {
// contains filtered or unexported fields
}
MockUsagesClientMockRecorder is the mock recorder for MockUsagesClient.
type MockVirtualNetworksClient ¶
type MockVirtualNetworksClient struct {
// contains filtered or unexported fields
}
MockVirtualNetworksClient is a mock of VirtualNetworksClient interface.
func NewMockVirtualNetworksClient ¶
func NewMockVirtualNetworksClient(ctrl *gomock.Controller) *MockVirtualNetworksClient
NewMockVirtualNetworksClient creates a new mock instance.
func (*MockVirtualNetworksClient) EXPECT ¶
func (m *MockVirtualNetworksClient) EXPECT() *MockVirtualNetworksClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockVirtualNetworksClient) Get ¶
func (m *MockVirtualNetworksClient) Get(ctx context.Context, resourceGroupName, virtualNetworkName string, options *armnetwork.VirtualNetworksClientGetOptions) (armnetwork.VirtualNetworksClientGetResponse, error)
Get mocks base method.
type MockVirtualNetworksClientMockRecorder ¶
type MockVirtualNetworksClientMockRecorder struct {
// contains filtered or unexported fields
}
MockVirtualNetworksClientMockRecorder is the mock recorder for MockVirtualNetworksClient.