Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GraphBaseServiceClient ¶
type GraphBaseServiceClient struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
GraphBaseServiceClient the main entry point of the SDK, exposes the configuration and the fluent API.
func NewGraphBaseServiceClient ¶
func NewGraphBaseServiceClient(requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter, backingStore ie8677ce2c7e1b4c22e9c3827ecd078d41185424dd9eeb92b7d971ed2d49a392e.BackingStoreFactory) *GraphBaseServiceClient
NewGraphBaseServiceClient instantiates a new GraphBaseServiceClient and sets the default values.
func (*GraphBaseServiceClient) Applications ¶
func (m *GraphBaseServiceClient) Applications() *ia0bade093e2fcd9f7a41174a662c74212f84f4e2ef8eb87d64804c29b438ea4b.ApplicationsRequestBuilder
Applications provides operations to manage the collection of application entities. returns a *ApplicationsRequestBuilder when successful
func (*GraphBaseServiceClient) ServicePrincipals ¶
func (m *GraphBaseServiceClient) ServicePrincipals() *i21d2bc42f470d02638054f9deafee77fbd37615ba9448f643193e6f39f53447a.ServicePrincipalsRequestBuilder
ServicePrincipals provides operations to manage the collection of servicePrincipal entities. returns a *ServicePrincipalsRequestBuilder when successful
Click to show internal directories.
Click to hide internal directories.