Documentation
¶
Index ¶
- func CreateItemAddPasswordPostRequestBodyFromDiscriminatorValue(...) (i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, ...)
- func ParseGetExpandQueryParameterType(v string) (any, error)
- func ParseGetOrderbyQueryParameterType(v string) (any, error)
- func ParseGetSelectQueryParameterType(v string) (any, error)
- func SerializeGetExpandQueryParameterType(values []GetExpandQueryParameterType) []string
- func SerializeGetOrderbyQueryParameterType(values []GetOrderbyQueryParameterType) []string
- func SerializeGetSelectQueryParameterType(values []GetSelectQueryParameterType) []string
- type ApplicationItemRequestBuilder
- func (m *ApplicationItemRequestBuilder) AddPassword() *ItemAddPasswordRequestBuilder
- func (m *ApplicationItemRequestBuilder) Delete(ctx context.Context, ...) error
- func (m *ApplicationItemRequestBuilder) Get(ctx context.Context, ...) (...)
- func (m *ApplicationItemRequestBuilder) Patch(ctx context.Context, ...) (...)
- func (m *ApplicationItemRequestBuilder) ToDeleteRequestInformation(ctx context.Context, ...) (...)
- func (m *ApplicationItemRequestBuilder) ToGetRequestInformation(ctx context.Context, ...) (...)
- func (m *ApplicationItemRequestBuilder) ToPatchRequestInformation(ctx context.Context, ...) (...)
- func (m *ApplicationItemRequestBuilder) WithUrl(rawUrl string) *ApplicationItemRequestBuilder
- type ApplicationItemRequestBuilderDeleteRequestConfiguration
- type ApplicationItemRequestBuilderGetQueryParameters
- type ApplicationItemRequestBuilderGetRequestConfiguration
- type ApplicationItemRequestBuilderPatchRequestConfiguration
- type ApplicationsRequestBuilder
- func (m *ApplicationsRequestBuilder) ByApplicationId(applicationId string) *ApplicationItemRequestBuilder
- func (m *ApplicationsRequestBuilder) Get(ctx context.Context, ...) (...)
- func (m *ApplicationsRequestBuilder) Post(ctx context.Context, ...) (...)
- func (m *ApplicationsRequestBuilder) ToGetRequestInformation(ctx context.Context, ...) (...)
- func (m *ApplicationsRequestBuilder) ToPostRequestInformation(ctx context.Context, ...) (...)
- func (m *ApplicationsRequestBuilder) WithUrl(rawUrl string) *ApplicationsRequestBuilder
- type ApplicationsRequestBuilderGetQueryParameters
- type ApplicationsRequestBuilderGetRequestConfiguration
- type ApplicationsRequestBuilderPostRequestConfiguration
- type GetExpandQueryParameterType
- type GetOrderbyQueryParameterType
- type GetSelectQueryParameterType
- type ItemAddPasswordPostRequestBody
- func (m *ItemAddPasswordPostRequestBody) GetBackingStore() ie8677ce2c7e1b4c22e9c3827ecd078d41185424dd9eeb92b7d971ed2d49a392e.BackingStore
- func (m *ItemAddPasswordPostRequestBody) GetFieldDeserializers() ...
- func (m *ItemAddPasswordPostRequestBody) GetPasswordCredential() ...
- func (m *ItemAddPasswordPostRequestBody) Serialize(...) error
- func (m *ItemAddPasswordPostRequestBody) SetBackingStore(...)
- func (m *ItemAddPasswordPostRequestBody) SetPasswordCredential(...)
- type ItemAddPasswordPostRequestBodyable
- type ItemAddPasswordRequestBuilder
- func (m *ItemAddPasswordRequestBuilder) Post(ctx context.Context, body ItemAddPasswordPostRequestBodyable, ...) (...)
- func (m *ItemAddPasswordRequestBuilder) ToPostRequestInformation(ctx context.Context, body ItemAddPasswordPostRequestBodyable, ...) (...)
- func (m *ItemAddPasswordRequestBuilder) WithUrl(rawUrl string) *ItemAddPasswordRequestBuilder
- type ItemAddPasswordRequestBuilderPostRequestConfiguration
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateItemAddPasswordPostRequestBodyFromDiscriminatorValue ¶
func CreateItemAddPasswordPostRequestBodyFromDiscriminatorValue(parseNode i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) (i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, error)
CreateItemAddPasswordPostRequestBodyFromDiscriminatorValue creates a new instance of the appropriate class based on discriminator value returns a Parsable when successful
func SerializeGetExpandQueryParameterType ¶
func SerializeGetExpandQueryParameterType(values []GetExpandQueryParameterType) []string
func SerializeGetOrderbyQueryParameterType ¶
func SerializeGetOrderbyQueryParameterType(values []GetOrderbyQueryParameterType) []string
func SerializeGetSelectQueryParameterType ¶
func SerializeGetSelectQueryParameterType(values []GetSelectQueryParameterType) []string
Types ¶
type ApplicationItemRequestBuilder ¶
type ApplicationItemRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
ApplicationItemRequestBuilder provides operations to manage the collection of application entities.
func NewApplicationItemRequestBuilder ¶
func NewApplicationItemRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ApplicationItemRequestBuilder
NewApplicationItemRequestBuilder instantiates a new ApplicationItemRequestBuilder and sets the default values.
func NewApplicationItemRequestBuilderInternal ¶
func NewApplicationItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ApplicationItemRequestBuilder
NewApplicationItemRequestBuilderInternal instantiates a new ApplicationItemRequestBuilder and sets the default values.
func (*ApplicationItemRequestBuilder) AddPassword ¶
func (m *ApplicationItemRequestBuilder) AddPassword() *ItemAddPasswordRequestBuilder
AddPassword provides operations to call the addPassword method. returns a *ItemAddPasswordRequestBuilder when successful
func (*ApplicationItemRequestBuilder) Delete ¶
func (m *ApplicationItemRequestBuilder) Delete(ctx context.Context, requestConfiguration *ApplicationItemRequestBuilderDeleteRequestConfiguration) error
Delete delete an application object. When deleted, apps are moved to a temporary container and can be restored within 30 days. After that time, they are permanently deleted. returns a ODataError error when the service returns a 4XX or 5XX status code Find more info here
func (*ApplicationItemRequestBuilder) Get ¶
func (m *ApplicationItemRequestBuilder) Get(ctx context.Context, requestConfiguration *ApplicationItemRequestBuilderGetRequestConfiguration) (i41bcc35ce32714d516294a23ce1c45d33e169802291ff51166cf13043c547b8a.Applicationable, error)
Get get the properties and relationships of an application object. returns a Applicationable when successful returns a ODataError error when the service returns a 4XX or 5XX status code Find more info here
func (*ApplicationItemRequestBuilder) Patch ¶
func (m *ApplicationItemRequestBuilder) Patch(ctx context.Context, body i41bcc35ce32714d516294a23ce1c45d33e169802291ff51166cf13043c547b8a.Applicationable, requestConfiguration *ApplicationItemRequestBuilderPatchRequestConfiguration) (i41bcc35ce32714d516294a23ce1c45d33e169802291ff51166cf13043c547b8a.Applicationable, error)
Patch update the properties of an application object. returns a Applicationable when successful returns a ODataError error when the service returns a 4XX or 5XX status code Find more info here
func (*ApplicationItemRequestBuilder) ToDeleteRequestInformation ¶
func (m *ApplicationItemRequestBuilder) ToDeleteRequestInformation(ctx context.Context, requestConfiguration *ApplicationItemRequestBuilderDeleteRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToDeleteRequestInformation delete an application object. When deleted, apps are moved to a temporary container and can be restored within 30 days. After that time, they are permanently deleted. returns a *RequestInformation when successful
func (*ApplicationItemRequestBuilder) ToGetRequestInformation ¶
func (m *ApplicationItemRequestBuilder) ToGetRequestInformation(ctx context.Context, requestConfiguration *ApplicationItemRequestBuilderGetRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToGetRequestInformation get the properties and relationships of an application object. returns a *RequestInformation when successful
func (*ApplicationItemRequestBuilder) ToPatchRequestInformation ¶
func (m *ApplicationItemRequestBuilder) ToPatchRequestInformation(ctx context.Context, body i41bcc35ce32714d516294a23ce1c45d33e169802291ff51166cf13043c547b8a.Applicationable, requestConfiguration *ApplicationItemRequestBuilderPatchRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPatchRequestInformation update the properties of an application object. returns a *RequestInformation when successful
func (*ApplicationItemRequestBuilder) WithUrl ¶
func (m *ApplicationItemRequestBuilder) WithUrl(rawUrl string) *ApplicationItemRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ApplicationItemRequestBuilder when successful
type ApplicationItemRequestBuilderDeleteRequestConfiguration ¶
type ApplicationItemRequestBuilderDeleteRequestConfiguration struct {
// Request headers
Headers *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestHeaders
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}
ApplicationItemRequestBuilderDeleteRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.
type ApplicationItemRequestBuilderGetQueryParameters ¶
type ApplicationItemRequestBuilderGetQueryParameters struct {
// Expand related entities
// Deprecated: This property is deprecated, use ExpandAsGetExpandQueryParameterType instead
Expand []string `uriparametername:"%24expand"`
// Expand related entities
ExpandAsGetExpandQueryParameterType []if3e3a6e3a40d435f915b6a21e829a1bcb671d794fcd24a1166bd894ceb170494.GetExpandQueryParameterType `uriparametername:"%24expand"`
// Select properties to be returned
// Deprecated: This property is deprecated, use SelectAsGetSelectQueryParameterType instead
Select []string `uriparametername:"%24select"`
// Select properties to be returned
SelectAsGetSelectQueryParameterType []if3e3a6e3a40d435f915b6a21e829a1bcb671d794fcd24a1166bd894ceb170494.GetSelectQueryParameterType `uriparametername:"%24select"`
}
ApplicationItemRequestBuilderGetQueryParameters get the properties and relationships of an application object.
type ApplicationItemRequestBuilderGetRequestConfiguration ¶
type ApplicationItemRequestBuilderGetRequestConfiguration struct {
// Request headers
Headers *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestHeaders
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
// Request query parameters
QueryParameters *ApplicationItemRequestBuilderGetQueryParameters
}
ApplicationItemRequestBuilderGetRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.
type ApplicationItemRequestBuilderPatchRequestConfiguration ¶
type ApplicationItemRequestBuilderPatchRequestConfiguration struct {
// Request headers
Headers *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestHeaders
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}
ApplicationItemRequestBuilderPatchRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.
type ApplicationsRequestBuilder ¶
type ApplicationsRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
ApplicationsRequestBuilder provides operations to manage the collection of application entities.
func NewApplicationsRequestBuilder ¶
func NewApplicationsRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ApplicationsRequestBuilder
NewApplicationsRequestBuilder instantiates a new ApplicationsRequestBuilder and sets the default values.
func NewApplicationsRequestBuilderInternal ¶
func NewApplicationsRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ApplicationsRequestBuilder
NewApplicationsRequestBuilderInternal instantiates a new ApplicationsRequestBuilder and sets the default values.
func (*ApplicationsRequestBuilder) ByApplicationId ¶
func (m *ApplicationsRequestBuilder) ByApplicationId(applicationId string) *ApplicationItemRequestBuilder
ByApplicationId provides operations to manage the collection of application entities. returns a *ApplicationItemRequestBuilder when successful
func (*ApplicationsRequestBuilder) Get ¶
func (m *ApplicationsRequestBuilder) Get(ctx context.Context, requestConfiguration *ApplicationsRequestBuilderGetRequestConfiguration) (i41bcc35ce32714d516294a23ce1c45d33e169802291ff51166cf13043c547b8a.ApplicationCollectionResponseable, error)
Get get the list of applications in this organization. returns a ApplicationCollectionResponseable when successful returns a ODataError error when the service returns a 4XX or 5XX status code Find more info here
func (*ApplicationsRequestBuilder) Post ¶
func (m *ApplicationsRequestBuilder) Post(ctx context.Context, body i41bcc35ce32714d516294a23ce1c45d33e169802291ff51166cf13043c547b8a.Applicationable, requestConfiguration *ApplicationsRequestBuilderPostRequestConfiguration) (i41bcc35ce32714d516294a23ce1c45d33e169802291ff51166cf13043c547b8a.Applicationable, error)
Post create a new application object. returns a Applicationable when successful returns a ODataError error when the service returns a 4XX or 5XX status code Find more info here
func (*ApplicationsRequestBuilder) ToGetRequestInformation ¶
func (m *ApplicationsRequestBuilder) ToGetRequestInformation(ctx context.Context, requestConfiguration *ApplicationsRequestBuilderGetRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToGetRequestInformation get the list of applications in this organization. returns a *RequestInformation when successful
func (*ApplicationsRequestBuilder) ToPostRequestInformation ¶
func (m *ApplicationsRequestBuilder) ToPostRequestInformation(ctx context.Context, body i41bcc35ce32714d516294a23ce1c45d33e169802291ff51166cf13043c547b8a.Applicationable, requestConfiguration *ApplicationsRequestBuilderPostRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPostRequestInformation create a new application object. returns a *RequestInformation when successful
func (*ApplicationsRequestBuilder) WithUrl ¶
func (m *ApplicationsRequestBuilder) WithUrl(rawUrl string) *ApplicationsRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ApplicationsRequestBuilder when successful
type ApplicationsRequestBuilderGetQueryParameters ¶
type ApplicationsRequestBuilderGetQueryParameters struct {
// Include count of items
Count *bool `uriparametername:"%24count"`
// Expand related entities
// Deprecated: This property is deprecated, use ExpandAsGetExpandQueryParameterType instead
Expand []string `uriparametername:"%24expand"`
// Expand related entities
ExpandAsGetExpandQueryParameterType []GetExpandQueryParameterType `uriparametername:"%24expand"`
// Filter items by property values
Filter *string `uriparametername:"%24filter"`
// Order items by property values
// Deprecated: This property is deprecated, use OrderbyAsGetOrderbyQueryParameterType instead
Orderby []string `uriparametername:"%24orderby"`
// Order items by property values
OrderbyAsGetOrderbyQueryParameterType []GetOrderbyQueryParameterType `uriparametername:"%24orderby"`
// Search items by search phrases
Search *string `uriparametername:"%24search"`
// Select properties to be returned
// Deprecated: This property is deprecated, use SelectAsGetSelectQueryParameterType instead
Select []string `uriparametername:"%24select"`
// Select properties to be returned
SelectAsGetSelectQueryParameterType []GetSelectQueryParameterType `uriparametername:"%24select"`
// Skip the first n items
Skip *int32 `uriparametername:"%24skip"`
// Show only the first n items
Top *int32 `uriparametername:"%24top"`
}
ApplicationsRequestBuilderGetQueryParameters get the list of applications in this organization.
type ApplicationsRequestBuilderGetRequestConfiguration ¶
type ApplicationsRequestBuilderGetRequestConfiguration struct {
// Request headers
Headers *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestHeaders
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
// Request query parameters
QueryParameters *ApplicationsRequestBuilderGetQueryParameters
}
ApplicationsRequestBuilderGetRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.
type ApplicationsRequestBuilderPostRequestConfiguration ¶
type ApplicationsRequestBuilderPostRequestConfiguration struct {
// Request headers
Headers *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestHeaders
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}
ApplicationsRequestBuilderPostRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.
type GetExpandQueryParameterType ¶
type GetExpandQueryParameterType int
Provides operations to manage the collection of application entities.
const ( ASTERISK_GETEXPANDQUERYPARAMETERTYPE GetExpandQueryParameterType = iota APPMANAGEMENTPOLICIES_GETEXPANDQUERYPARAMETERTYPE CREATEDONBEHALFOF_GETEXPANDQUERYPARAMETERTYPE EXTENSIONPROPERTIES_GETEXPANDQUERYPARAMETERTYPE FEDERATEDIDENTITYCREDENTIALS_GETEXPANDQUERYPARAMETERTYPE HOMEREALMDISCOVERYPOLICIES_GETEXPANDQUERYPARAMETERTYPE OWNERS_GETEXPANDQUERYPARAMETERTYPE TOKENISSUANCEPOLICIES_GETEXPANDQUERYPARAMETERTYPE TOKENLIFETIMEPOLICIES_GETEXPANDQUERYPARAMETERTYPE SYNCHRONIZATION_GETEXPANDQUERYPARAMETERTYPE )
func (GetExpandQueryParameterType) String ¶
func (i GetExpandQueryParameterType) String() string
type GetOrderbyQueryParameterType ¶
type GetOrderbyQueryParameterType int
Provides operations to manage the collection of application entities.
const ( ID_GETORDERBYQUERYPARAMETERTYPE GetOrderbyQueryParameterType = iota IDDESC_GETORDERBYQUERYPARAMETERTYPE DELETEDDATETIME_GETORDERBYQUERYPARAMETERTYPE DELETEDDATETIMEDESC_GETORDERBYQUERYPARAMETERTYPE ADDINS_GETORDERBYQUERYPARAMETERTYPE ADDINSDESC_GETORDERBYQUERYPARAMETERTYPE API_GETORDERBYQUERYPARAMETERTYPE APIDESC_GETORDERBYQUERYPARAMETERTYPE APPID_GETORDERBYQUERYPARAMETERTYPE APPIDDESC_GETORDERBYQUERYPARAMETERTYPE APPLICATIONTEMPLATEID_GETORDERBYQUERYPARAMETERTYPE APPLICATIONTEMPLATEIDDESC_GETORDERBYQUERYPARAMETERTYPE APPROLES_GETORDERBYQUERYPARAMETERTYPE APPROLESDESC_GETORDERBYQUERYPARAMETERTYPE CERTIFICATION_GETORDERBYQUERYPARAMETERTYPE CERTIFICATIONDESC_GETORDERBYQUERYPARAMETERTYPE CREATEDDATETIME_GETORDERBYQUERYPARAMETERTYPE CREATEDDATETIMEDESC_GETORDERBYQUERYPARAMETERTYPE DEFAULTREDIRECTURI_GETORDERBYQUERYPARAMETERTYPE DEFAULTREDIRECTURIDESC_GETORDERBYQUERYPARAMETERTYPE DESCRIPTION_GETORDERBYQUERYPARAMETERTYPE DESCRIPTIONDESC_GETORDERBYQUERYPARAMETERTYPE DISABLEDBYMICROSOFTSTATUS_GETORDERBYQUERYPARAMETERTYPE DISABLEDBYMICROSOFTSTATUSDESC_GETORDERBYQUERYPARAMETERTYPE DISPLAYNAME_GETORDERBYQUERYPARAMETERTYPE DISPLAYNAMEDESC_GETORDERBYQUERYPARAMETERTYPE GROUPMEMBERSHIPCLAIMS_GETORDERBYQUERYPARAMETERTYPE GROUPMEMBERSHIPCLAIMSDESC_GETORDERBYQUERYPARAMETERTYPE IDENTIFIERURIS_GETORDERBYQUERYPARAMETERTYPE IDENTIFIERURISDESC_GETORDERBYQUERYPARAMETERTYPE INFO_GETORDERBYQUERYPARAMETERTYPE INFODESC_GETORDERBYQUERYPARAMETERTYPE ISDEVICEONLYAUTHSUPPORTED_GETORDERBYQUERYPARAMETERTYPE ISDEVICEONLYAUTHSUPPORTEDDESC_GETORDERBYQUERYPARAMETERTYPE ISFALLBACKPUBLICCLIENT_GETORDERBYQUERYPARAMETERTYPE ISFALLBACKPUBLICCLIENTDESC_GETORDERBYQUERYPARAMETERTYPE KEYCREDENTIALS_GETORDERBYQUERYPARAMETERTYPE KEYCREDENTIALSDESC_GETORDERBYQUERYPARAMETERTYPE LOGO_GETORDERBYQUERYPARAMETERTYPE LOGODESC_GETORDERBYQUERYPARAMETERTYPE NOTES_GETORDERBYQUERYPARAMETERTYPE NOTESDESC_GETORDERBYQUERYPARAMETERTYPE OAUTH2REQUIREPOSTRESPONSE_GETORDERBYQUERYPARAMETERTYPE OAUTH2REQUIREPOSTRESPONSEDESC_GETORDERBYQUERYPARAMETERTYPE OPTIONALCLAIMS_GETORDERBYQUERYPARAMETERTYPE OPTIONALCLAIMSDESC_GETORDERBYQUERYPARAMETERTYPE PARENTALCONTROLSETTINGS_GETORDERBYQUERYPARAMETERTYPE PARENTALCONTROLSETTINGSDESC_GETORDERBYQUERYPARAMETERTYPE PASSWORDCREDENTIALS_GETORDERBYQUERYPARAMETERTYPE PASSWORDCREDENTIALSDESC_GETORDERBYQUERYPARAMETERTYPE PUBLICCLIENT_GETORDERBYQUERYPARAMETERTYPE PUBLICCLIENTDESC_GETORDERBYQUERYPARAMETERTYPE PUBLISHERDOMAIN_GETORDERBYQUERYPARAMETERTYPE PUBLISHERDOMAINDESC_GETORDERBYQUERYPARAMETERTYPE REQUESTSIGNATUREVERIFICATION_GETORDERBYQUERYPARAMETERTYPE REQUESTSIGNATUREVERIFICATIONDESC_GETORDERBYQUERYPARAMETERTYPE REQUIREDRESOURCEACCESS_GETORDERBYQUERYPARAMETERTYPE REQUIREDRESOURCEACCESSDESC_GETORDERBYQUERYPARAMETERTYPE SAMLMETADATAURL_GETORDERBYQUERYPARAMETERTYPE SAMLMETADATAURLDESC_GETORDERBYQUERYPARAMETERTYPE SERVICEMANAGEMENTREFERENCE_GETORDERBYQUERYPARAMETERTYPE SERVICEMANAGEMENTREFERENCEDESC_GETORDERBYQUERYPARAMETERTYPE SIGNINAUDIENCE_GETORDERBYQUERYPARAMETERTYPE SIGNINAUDIENCEDESC_GETORDERBYQUERYPARAMETERTYPE SPA_GETORDERBYQUERYPARAMETERTYPE SPADESC_GETORDERBYQUERYPARAMETERTYPE TAGS_GETORDERBYQUERYPARAMETERTYPE TAGSDESC_GETORDERBYQUERYPARAMETERTYPE TOKENENCRYPTIONKEYID_GETORDERBYQUERYPARAMETERTYPE TOKENENCRYPTIONKEYIDDESC_GETORDERBYQUERYPARAMETERTYPE VERIFIEDPUBLISHER_GETORDERBYQUERYPARAMETERTYPE VERIFIEDPUBLISHERDESC_GETORDERBYQUERYPARAMETERTYPE WEB_GETORDERBYQUERYPARAMETERTYPE WEBDESC_GETORDERBYQUERYPARAMETERTYPE )
func (GetOrderbyQueryParameterType) String ¶
func (i GetOrderbyQueryParameterType) String() string
type GetSelectQueryParameterType ¶
type GetSelectQueryParameterType int
Provides operations to manage the collection of application entities.
const ( ID_GETSELECTQUERYPARAMETERTYPE GetSelectQueryParameterType = iota DELETEDDATETIME_GETSELECTQUERYPARAMETERTYPE ADDINS_GETSELECTQUERYPARAMETERTYPE API_GETSELECTQUERYPARAMETERTYPE APPID_GETSELECTQUERYPARAMETERTYPE APPLICATIONTEMPLATEID_GETSELECTQUERYPARAMETERTYPE APPROLES_GETSELECTQUERYPARAMETERTYPE CERTIFICATION_GETSELECTQUERYPARAMETERTYPE CREATEDDATETIME_GETSELECTQUERYPARAMETERTYPE DEFAULTREDIRECTURI_GETSELECTQUERYPARAMETERTYPE DESCRIPTION_GETSELECTQUERYPARAMETERTYPE DISABLEDBYMICROSOFTSTATUS_GETSELECTQUERYPARAMETERTYPE DISPLAYNAME_GETSELECTQUERYPARAMETERTYPE GROUPMEMBERSHIPCLAIMS_GETSELECTQUERYPARAMETERTYPE IDENTIFIERURIS_GETSELECTQUERYPARAMETERTYPE INFO_GETSELECTQUERYPARAMETERTYPE ISDEVICEONLYAUTHSUPPORTED_GETSELECTQUERYPARAMETERTYPE ISFALLBACKPUBLICCLIENT_GETSELECTQUERYPARAMETERTYPE KEYCREDENTIALS_GETSELECTQUERYPARAMETERTYPE LOGO_GETSELECTQUERYPARAMETERTYPE NOTES_GETSELECTQUERYPARAMETERTYPE OAUTH2REQUIREPOSTRESPONSE_GETSELECTQUERYPARAMETERTYPE OPTIONALCLAIMS_GETSELECTQUERYPARAMETERTYPE PARENTALCONTROLSETTINGS_GETSELECTQUERYPARAMETERTYPE PASSWORDCREDENTIALS_GETSELECTQUERYPARAMETERTYPE PUBLICCLIENT_GETSELECTQUERYPARAMETERTYPE PUBLISHERDOMAIN_GETSELECTQUERYPARAMETERTYPE REQUESTSIGNATUREVERIFICATION_GETSELECTQUERYPARAMETERTYPE REQUIREDRESOURCEACCESS_GETSELECTQUERYPARAMETERTYPE SAMLMETADATAURL_GETSELECTQUERYPARAMETERTYPE SERVICEMANAGEMENTREFERENCE_GETSELECTQUERYPARAMETERTYPE SIGNINAUDIENCE_GETSELECTQUERYPARAMETERTYPE SPA_GETSELECTQUERYPARAMETERTYPE TAGS_GETSELECTQUERYPARAMETERTYPE TOKENENCRYPTIONKEYID_GETSELECTQUERYPARAMETERTYPE VERIFIEDPUBLISHER_GETSELECTQUERYPARAMETERTYPE WEB_GETSELECTQUERYPARAMETERTYPE APPMANAGEMENTPOLICIES_GETSELECTQUERYPARAMETERTYPE CREATEDONBEHALFOF_GETSELECTQUERYPARAMETERTYPE EXTENSIONPROPERTIES_GETSELECTQUERYPARAMETERTYPE FEDERATEDIDENTITYCREDENTIALS_GETSELECTQUERYPARAMETERTYPE HOMEREALMDISCOVERYPOLICIES_GETSELECTQUERYPARAMETERTYPE OWNERS_GETSELECTQUERYPARAMETERTYPE TOKENISSUANCEPOLICIES_GETSELECTQUERYPARAMETERTYPE TOKENLIFETIMEPOLICIES_GETSELECTQUERYPARAMETERTYPE SYNCHRONIZATION_GETSELECTQUERYPARAMETERTYPE )
func (GetSelectQueryParameterType) String ¶
func (i GetSelectQueryParameterType) String() string
type ItemAddPasswordPostRequestBody ¶
type ItemAddPasswordPostRequestBody struct {
// contains filtered or unexported fields
}
func NewItemAddPasswordPostRequestBody ¶
func NewItemAddPasswordPostRequestBody() *ItemAddPasswordPostRequestBody
NewItemAddPasswordPostRequestBody instantiates a new ItemAddPasswordPostRequestBody and sets the default values.
func (*ItemAddPasswordPostRequestBody) GetBackingStore ¶
func (m *ItemAddPasswordPostRequestBody) GetBackingStore() ie8677ce2c7e1b4c22e9c3827ecd078d41185424dd9eeb92b7d971ed2d49a392e.BackingStore
GetBackingStore gets the BackingStore property value. Stores model information. returns a BackingStore when successful
func (*ItemAddPasswordPostRequestBody) GetFieldDeserializers ¶
func (m *ItemAddPasswordPostRequestBody) GetFieldDeserializers() map[string]func(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error
GetFieldDeserializers the deserialization information for the current model returns a map[string]func(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode)(error) when successful
func (*ItemAddPasswordPostRequestBody) GetPasswordCredential ¶
func (m *ItemAddPasswordPostRequestBody) GetPasswordCredential() i41bcc35ce32714d516294a23ce1c45d33e169802291ff51166cf13043c547b8a.PasswordCredentialable
GetPasswordCredential gets the passwordCredential property value. The passwordCredential property returns a PasswordCredentialable when successful
func (*ItemAddPasswordPostRequestBody) Serialize ¶
func (m *ItemAddPasswordPostRequestBody) Serialize(writer i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.SerializationWriter) error
Serialize serializes information the current object
func (*ItemAddPasswordPostRequestBody) SetBackingStore ¶
func (m *ItemAddPasswordPostRequestBody) SetBackingStore(value ie8677ce2c7e1b4c22e9c3827ecd078d41185424dd9eeb92b7d971ed2d49a392e.BackingStore)
SetBackingStore sets the BackingStore property value. Stores model information.
func (*ItemAddPasswordPostRequestBody) SetPasswordCredential ¶
func (m *ItemAddPasswordPostRequestBody) SetPasswordCredential(value i41bcc35ce32714d516294a23ce1c45d33e169802291ff51166cf13043c547b8a.PasswordCredentialable)
SetPasswordCredential sets the passwordCredential property value. The passwordCredential property
type ItemAddPasswordPostRequestBodyable ¶
type ItemAddPasswordPostRequestBodyable interface {
ie8677ce2c7e1b4c22e9c3827ecd078d41185424dd9eeb92b7d971ed2d49a392e.BackedModel
i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable
GetBackingStore() ie8677ce2c7e1b4c22e9c3827ecd078d41185424dd9eeb92b7d971ed2d49a392e.BackingStore
GetPasswordCredential() i41bcc35ce32714d516294a23ce1c45d33e169802291ff51166cf13043c547b8a.PasswordCredentialable
SetBackingStore(value ie8677ce2c7e1b4c22e9c3827ecd078d41185424dd9eeb92b7d971ed2d49a392e.BackingStore)
SetPasswordCredential(value i41bcc35ce32714d516294a23ce1c45d33e169802291ff51166cf13043c547b8a.PasswordCredentialable)
}
type ItemAddPasswordRequestBuilder ¶
type ItemAddPasswordRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
ItemAddPasswordRequestBuilder provides operations to call the addPassword method.
func NewItemAddPasswordRequestBuilder ¶
func NewItemAddPasswordRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemAddPasswordRequestBuilder
NewItemAddPasswordRequestBuilder instantiates a new ItemAddPasswordRequestBuilder and sets the default values.
func NewItemAddPasswordRequestBuilderInternal ¶
func NewItemAddPasswordRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemAddPasswordRequestBuilder
NewItemAddPasswordRequestBuilderInternal instantiates a new ItemAddPasswordRequestBuilder and sets the default values.
func (*ItemAddPasswordRequestBuilder) Post ¶
func (m *ItemAddPasswordRequestBuilder) Post(ctx context.Context, body ItemAddPasswordPostRequestBodyable, requestConfiguration *ItemAddPasswordRequestBuilderPostRequestConfiguration) (i41bcc35ce32714d516294a23ce1c45d33e169802291ff51166cf13043c547b8a.PasswordCredentialable, error)
Post adds a strong password or secret to an application. returns a PasswordCredentialable when successful returns a ODataError error when the service returns a 4XX or 5XX status code Find more info here
func (*ItemAddPasswordRequestBuilder) ToPostRequestInformation ¶
func (m *ItemAddPasswordRequestBuilder) ToPostRequestInformation(ctx context.Context, body ItemAddPasswordPostRequestBodyable, requestConfiguration *ItemAddPasswordRequestBuilderPostRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPostRequestInformation adds a strong password or secret to an application. returns a *RequestInformation when successful
func (*ItemAddPasswordRequestBuilder) WithUrl ¶
func (m *ItemAddPasswordRequestBuilder) WithUrl(rawUrl string) *ItemAddPasswordRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ItemAddPasswordRequestBuilder when successful
type ItemAddPasswordRequestBuilderPostRequestConfiguration ¶
type ItemAddPasswordRequestBuilderPostRequestConfiguration struct {
// Request headers
Headers *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestHeaders
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}
ItemAddPasswordRequestBuilderPostRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.