Documentation
¶
Overview ¶
Package mock_compute is a generated GoMock package.
Index ¶
- type MockDiskEncryptionSetsClient
- type MockDiskEncryptionSetsClientMockRecorder
- type MockDisksClient
- type MockDisksClientMockRecorder
- type MockUsageClient
- type MockUsageClientMockRecorder
- type MockVirtualMachineScaleSetVMsClient
- func (m *MockVirtualMachineScaleSetVMsClient) EXPECT() *MockVirtualMachineScaleSetVMsClientMockRecorder
- func (m *MockVirtualMachineScaleSetVMsClient) GetInstanceView(ctx context.Context, resourceGroupName, VMScaleSetName, instanceID string) (compute.VirtualMachineScaleSetVMInstanceView, error)
- func (m *MockVirtualMachineScaleSetVMsClient) List(ctx context.Context, ...) ([]compute.VirtualMachineScaleSetVM, error)
- func (m *MockVirtualMachineScaleSetVMsClient) RunCommandAndWait(ctx context.Context, resourceGroupName, VMScaleSetName, instanceID string, ...) error
- type MockVirtualMachineScaleSetVMsClientMockRecorder
- func (mr *MockVirtualMachineScaleSetVMsClientMockRecorder) GetInstanceView(ctx, resourceGroupName, VMScaleSetName, instanceID any) *gomock.Call
- func (mr *MockVirtualMachineScaleSetVMsClientMockRecorder) List(...) *gomock.Call
- func (mr *MockVirtualMachineScaleSetVMsClientMockRecorder) RunCommandAndWait(ctx, resourceGroupName, VMScaleSetName, instanceID, parameters any) *gomock.Call
- type MockVirtualMachineScaleSetsClient
- func (m *MockVirtualMachineScaleSetsClient) DeleteAndWait(ctx context.Context, resourceGroupName, vmScaleSetName string) error
- func (m *MockVirtualMachineScaleSetsClient) EXPECT() *MockVirtualMachineScaleSetsClientMockRecorder
- func (m *MockVirtualMachineScaleSetsClient) List(ctx context.Context, resourceGroupName string) ([]compute.VirtualMachineScaleSet, error)
- func (m *MockVirtualMachineScaleSetsClient) UpdateAndWait(ctx context.Context, resourceGroupName, vmScaleSetName string, ...) error
- type MockVirtualMachineScaleSetsClientMockRecorder
- func (mr *MockVirtualMachineScaleSetsClientMockRecorder) DeleteAndWait(ctx, resourceGroupName, vmScaleSetName any) *gomock.Call
- func (mr *MockVirtualMachineScaleSetsClientMockRecorder) List(ctx, resourceGroupName any) *gomock.Call
- func (mr *MockVirtualMachineScaleSetsClientMockRecorder) UpdateAndWait(ctx, resourceGroupName, vmScaleSetName, parameters any) *gomock.Call
- type MockVirtualMachinesClient
- func (m *MockVirtualMachinesClient) CreateOrUpdateAndWait(ctx context.Context, resourceGroupName, VMName string, ...) error
- func (m *MockVirtualMachinesClient) DeleteAndWait(ctx context.Context, resourceGroupName, VMName string, forceDeletion *bool) error
- func (m *MockVirtualMachinesClient) EXPECT() *MockVirtualMachinesClientMockRecorder
- func (m *MockVirtualMachinesClient) Get(ctx context.Context, resourceGroupName, VMName string, ...) (compute.VirtualMachine, error)
- func (m *MockVirtualMachinesClient) GetSerialConsoleForVM(ctx context.Context, resourceGroupName, VMName string, target io.Writer) error
- func (m *MockVirtualMachinesClient) List(ctx context.Context, resourceGroupName string) ([]compute.VirtualMachine, error)
- func (m *MockVirtualMachinesClient) RedeployAndWait(ctx context.Context, resourceGroupName, VMName string) error
- func (m *MockVirtualMachinesClient) StartAndWait(ctx context.Context, resourceGroupName, VMName string) error
- func (m *MockVirtualMachinesClient) StopAndWait(ctx context.Context, resourceGroupName, VMName string, deallocateVM bool) error
- type MockVirtualMachinesClientMockRecorder
- func (mr *MockVirtualMachinesClientMockRecorder) CreateOrUpdateAndWait(ctx, resourceGroupName, VMName, parameters any) *gomock.Call
- func (mr *MockVirtualMachinesClientMockRecorder) DeleteAndWait(ctx, resourceGroupName, VMName, forceDeletion any) *gomock.Call
- func (mr *MockVirtualMachinesClientMockRecorder) Get(ctx, resourceGroupName, VMName, expand any) *gomock.Call
- func (mr *MockVirtualMachinesClientMockRecorder) GetSerialConsoleForVM(ctx, resourceGroupName, VMName, target any) *gomock.Call
- func (mr *MockVirtualMachinesClientMockRecorder) List(ctx, resourceGroupName any) *gomock.Call
- func (mr *MockVirtualMachinesClientMockRecorder) RedeployAndWait(ctx, resourceGroupName, VMName any) *gomock.Call
- func (mr *MockVirtualMachinesClientMockRecorder) StartAndWait(ctx, resourceGroupName, VMName any) *gomock.Call
- func (mr *MockVirtualMachinesClientMockRecorder) StopAndWait(ctx, resourceGroupName, VMName, deallocateVM any) *gomock.Call
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockDiskEncryptionSetsClient ¶
type MockDiskEncryptionSetsClient struct {
// contains filtered or unexported fields
}
MockDiskEncryptionSetsClient is a mock of DiskEncryptionSetsClient interface.
func NewMockDiskEncryptionSetsClient ¶
func NewMockDiskEncryptionSetsClient(ctrl *gomock.Controller) *MockDiskEncryptionSetsClient
NewMockDiskEncryptionSetsClient creates a new mock instance.
func (*MockDiskEncryptionSetsClient) EXPECT ¶
func (m *MockDiskEncryptionSetsClient) EXPECT() *MockDiskEncryptionSetsClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockDiskEncryptionSetsClient) Get ¶
func (m *MockDiskEncryptionSetsClient) Get(ctx context.Context, resourceGroupName, diskEncryptionSetName string) (compute.DiskEncryptionSet, error)
Get mocks base method.
type MockDiskEncryptionSetsClientMockRecorder ¶
type MockDiskEncryptionSetsClientMockRecorder struct {
// contains filtered or unexported fields
}
MockDiskEncryptionSetsClientMockRecorder is the mock recorder for MockDiskEncryptionSetsClient.
type MockDisksClient ¶
type MockDisksClient struct {
// contains filtered or unexported fields
}
MockDisksClient is a mock of DisksClient interface.
func NewMockDisksClient ¶
func NewMockDisksClient(ctrl *gomock.Controller) *MockDisksClient
NewMockDisksClient creates a new mock instance.
func (*MockDisksClient) DeleteAndWait ¶
func (m *MockDisksClient) DeleteAndWait(ctx context.Context, resourceGroupName, diskName string) error
DeleteAndWait mocks base method.
func (*MockDisksClient) EXPECT ¶
func (m *MockDisksClient) EXPECT() *MockDisksClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockDisksClientMockRecorder ¶
type MockDisksClientMockRecorder struct {
// contains filtered or unexported fields
}
MockDisksClientMockRecorder is the mock recorder for MockDisksClient.
func (*MockDisksClientMockRecorder) DeleteAndWait ¶
func (mr *MockDisksClientMockRecorder) DeleteAndWait(ctx, resourceGroupName, diskName any) *gomock.Call
DeleteAndWait indicates an expected call of DeleteAndWait.
type MockUsageClient ¶
type MockUsageClient struct {
// contains filtered or unexported fields
}
MockUsageClient is a mock of UsageClient interface.
func NewMockUsageClient ¶
func NewMockUsageClient(ctrl *gomock.Controller) *MockUsageClient
NewMockUsageClient creates a new mock instance.
func (*MockUsageClient) EXPECT ¶
func (m *MockUsageClient) EXPECT() *MockUsageClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockUsageClientMockRecorder ¶
type MockUsageClientMockRecorder struct {
// contains filtered or unexported fields
}
MockUsageClientMockRecorder is the mock recorder for MockUsageClient.
type MockVirtualMachineScaleSetVMsClient ¶
type MockVirtualMachineScaleSetVMsClient struct {
// contains filtered or unexported fields
}
MockVirtualMachineScaleSetVMsClient is a mock of VirtualMachineScaleSetVMsClient interface.
func NewMockVirtualMachineScaleSetVMsClient ¶
func NewMockVirtualMachineScaleSetVMsClient(ctrl *gomock.Controller) *MockVirtualMachineScaleSetVMsClient
NewMockVirtualMachineScaleSetVMsClient creates a new mock instance.
func (*MockVirtualMachineScaleSetVMsClient) EXPECT ¶
func (m *MockVirtualMachineScaleSetVMsClient) EXPECT() *MockVirtualMachineScaleSetVMsClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockVirtualMachineScaleSetVMsClient) GetInstanceView ¶
func (m *MockVirtualMachineScaleSetVMsClient) GetInstanceView(ctx context.Context, resourceGroupName, VMScaleSetName, instanceID string) (compute.VirtualMachineScaleSetVMInstanceView, error)
GetInstanceView mocks base method.
func (*MockVirtualMachineScaleSetVMsClient) List ¶
func (m *MockVirtualMachineScaleSetVMsClient) List(ctx context.Context, resourceGroupName, virtualMachineScaleSetName, filter, selectParameter, expand string) ([]compute.VirtualMachineScaleSetVM, error)
List mocks base method.
func (*MockVirtualMachineScaleSetVMsClient) RunCommandAndWait ¶
func (m *MockVirtualMachineScaleSetVMsClient) RunCommandAndWait(ctx context.Context, resourceGroupName, VMScaleSetName, instanceID string, parameters compute.RunCommandInput) error
RunCommandAndWait mocks base method.
type MockVirtualMachineScaleSetVMsClientMockRecorder ¶
type MockVirtualMachineScaleSetVMsClientMockRecorder struct {
// contains filtered or unexported fields
}
MockVirtualMachineScaleSetVMsClientMockRecorder is the mock recorder for MockVirtualMachineScaleSetVMsClient.
func (*MockVirtualMachineScaleSetVMsClientMockRecorder) GetInstanceView ¶
func (mr *MockVirtualMachineScaleSetVMsClientMockRecorder) GetInstanceView(ctx, resourceGroupName, VMScaleSetName, instanceID any) *gomock.Call
GetInstanceView indicates an expected call of GetInstanceView.
func (*MockVirtualMachineScaleSetVMsClientMockRecorder) List ¶
func (mr *MockVirtualMachineScaleSetVMsClientMockRecorder) List(ctx, resourceGroupName, virtualMachineScaleSetName, filter, selectParameter, expand any) *gomock.Call
List indicates an expected call of List.
func (*MockVirtualMachineScaleSetVMsClientMockRecorder) RunCommandAndWait ¶
func (mr *MockVirtualMachineScaleSetVMsClientMockRecorder) RunCommandAndWait(ctx, resourceGroupName, VMScaleSetName, instanceID, parameters any) *gomock.Call
RunCommandAndWait indicates an expected call of RunCommandAndWait.
type MockVirtualMachineScaleSetsClient ¶
type MockVirtualMachineScaleSetsClient struct {
// contains filtered or unexported fields
}
MockVirtualMachineScaleSetsClient is a mock of VirtualMachineScaleSetsClient interface.
func NewMockVirtualMachineScaleSetsClient ¶
func NewMockVirtualMachineScaleSetsClient(ctrl *gomock.Controller) *MockVirtualMachineScaleSetsClient
NewMockVirtualMachineScaleSetsClient creates a new mock instance.
func (*MockVirtualMachineScaleSetsClient) DeleteAndWait ¶
func (m *MockVirtualMachineScaleSetsClient) DeleteAndWait(ctx context.Context, resourceGroupName, vmScaleSetName string) error
DeleteAndWait mocks base method.
func (*MockVirtualMachineScaleSetsClient) EXPECT ¶
func (m *MockVirtualMachineScaleSetsClient) EXPECT() *MockVirtualMachineScaleSetsClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockVirtualMachineScaleSetsClient) List ¶
func (m *MockVirtualMachineScaleSetsClient) List(ctx context.Context, resourceGroupName string) ([]compute.VirtualMachineScaleSet, error)
List mocks base method.
func (*MockVirtualMachineScaleSetsClient) UpdateAndWait ¶
func (m *MockVirtualMachineScaleSetsClient) UpdateAndWait(ctx context.Context, resourceGroupName, vmScaleSetName string, parameters compute.VirtualMachineScaleSetUpdate) error
UpdateAndWait mocks base method.
type MockVirtualMachineScaleSetsClientMockRecorder ¶
type MockVirtualMachineScaleSetsClientMockRecorder struct {
// contains filtered or unexported fields
}
MockVirtualMachineScaleSetsClientMockRecorder is the mock recorder for MockVirtualMachineScaleSetsClient.
func (*MockVirtualMachineScaleSetsClientMockRecorder) DeleteAndWait ¶
func (mr *MockVirtualMachineScaleSetsClientMockRecorder) DeleteAndWait(ctx, resourceGroupName, vmScaleSetName any) *gomock.Call
DeleteAndWait indicates an expected call of DeleteAndWait.
func (*MockVirtualMachineScaleSetsClientMockRecorder) List ¶
func (mr *MockVirtualMachineScaleSetsClientMockRecorder) List(ctx, resourceGroupName any) *gomock.Call
List indicates an expected call of List.
func (*MockVirtualMachineScaleSetsClientMockRecorder) UpdateAndWait ¶
func (mr *MockVirtualMachineScaleSetsClientMockRecorder) UpdateAndWait(ctx, resourceGroupName, vmScaleSetName, parameters any) *gomock.Call
UpdateAndWait indicates an expected call of UpdateAndWait.
type MockVirtualMachinesClient ¶
type MockVirtualMachinesClient struct {
// contains filtered or unexported fields
}
MockVirtualMachinesClient is a mock of VirtualMachinesClient interface.
func NewMockVirtualMachinesClient ¶
func NewMockVirtualMachinesClient(ctrl *gomock.Controller) *MockVirtualMachinesClient
NewMockVirtualMachinesClient creates a new mock instance.
func (*MockVirtualMachinesClient) CreateOrUpdateAndWait ¶
func (m *MockVirtualMachinesClient) CreateOrUpdateAndWait(ctx context.Context, resourceGroupName, VMName string, parameters compute.VirtualMachine) error
CreateOrUpdateAndWait mocks base method.
func (*MockVirtualMachinesClient) DeleteAndWait ¶
func (m *MockVirtualMachinesClient) DeleteAndWait(ctx context.Context, resourceGroupName, VMName string, forceDeletion *bool) error
DeleteAndWait mocks base method.
func (*MockVirtualMachinesClient) EXPECT ¶
func (m *MockVirtualMachinesClient) EXPECT() *MockVirtualMachinesClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockVirtualMachinesClient) Get ¶
func (m *MockVirtualMachinesClient) Get(ctx context.Context, resourceGroupName, VMName string, expand compute.InstanceViewTypes) (compute.VirtualMachine, error)
Get mocks base method.
func (*MockVirtualMachinesClient) GetSerialConsoleForVM ¶
func (m *MockVirtualMachinesClient) GetSerialConsoleForVM(ctx context.Context, resourceGroupName, VMName string, target io.Writer) error
GetSerialConsoleForVM mocks base method.
func (*MockVirtualMachinesClient) List ¶
func (m *MockVirtualMachinesClient) List(ctx context.Context, resourceGroupName string) ([]compute.VirtualMachine, error)
List mocks base method.
func (*MockVirtualMachinesClient) RedeployAndWait ¶
func (m *MockVirtualMachinesClient) RedeployAndWait(ctx context.Context, resourceGroupName, VMName string) error
RedeployAndWait mocks base method.
func (*MockVirtualMachinesClient) StartAndWait ¶
func (m *MockVirtualMachinesClient) StartAndWait(ctx context.Context, resourceGroupName, VMName string) error
StartAndWait mocks base method.
func (*MockVirtualMachinesClient) StopAndWait ¶
func (m *MockVirtualMachinesClient) StopAndWait(ctx context.Context, resourceGroupName, VMName string, deallocateVM bool) error
StopAndWait mocks base method.
type MockVirtualMachinesClientMockRecorder ¶
type MockVirtualMachinesClientMockRecorder struct {
// contains filtered or unexported fields
}
MockVirtualMachinesClientMockRecorder is the mock recorder for MockVirtualMachinesClient.
func (*MockVirtualMachinesClientMockRecorder) CreateOrUpdateAndWait ¶
func (mr *MockVirtualMachinesClientMockRecorder) CreateOrUpdateAndWait(ctx, resourceGroupName, VMName, parameters any) *gomock.Call
CreateOrUpdateAndWait indicates an expected call of CreateOrUpdateAndWait.
func (*MockVirtualMachinesClientMockRecorder) DeleteAndWait ¶
func (mr *MockVirtualMachinesClientMockRecorder) DeleteAndWait(ctx, resourceGroupName, VMName, forceDeletion any) *gomock.Call
DeleteAndWait indicates an expected call of DeleteAndWait.
func (*MockVirtualMachinesClientMockRecorder) Get ¶
func (mr *MockVirtualMachinesClientMockRecorder) Get(ctx, resourceGroupName, VMName, expand any) *gomock.Call
Get indicates an expected call of Get.
func (*MockVirtualMachinesClientMockRecorder) GetSerialConsoleForVM ¶
func (mr *MockVirtualMachinesClientMockRecorder) GetSerialConsoleForVM(ctx, resourceGroupName, VMName, target any) *gomock.Call
GetSerialConsoleForVM indicates an expected call of GetSerialConsoleForVM.
func (*MockVirtualMachinesClientMockRecorder) List ¶
func (mr *MockVirtualMachinesClientMockRecorder) List(ctx, resourceGroupName any) *gomock.Call
List indicates an expected call of List.
func (*MockVirtualMachinesClientMockRecorder) RedeployAndWait ¶
func (mr *MockVirtualMachinesClientMockRecorder) RedeployAndWait(ctx, resourceGroupName, VMName any) *gomock.Call
RedeployAndWait indicates an expected call of RedeployAndWait.
func (*MockVirtualMachinesClientMockRecorder) StartAndWait ¶
func (mr *MockVirtualMachinesClientMockRecorder) StartAndWait(ctx, resourceGroupName, VMName any) *gomock.Call
StartAndWait indicates an expected call of StartAndWait.
func (*MockVirtualMachinesClientMockRecorder) StopAndWait ¶
func (mr *MockVirtualMachinesClientMockRecorder) StopAndWait(ctx, resourceGroupName, VMName, deallocateVM any) *gomock.Call
StopAndWait indicates an expected call of StopAndWait.